Class: Google::Apis::DataformV1beta1::Assertion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents an assertion upon a SQL query which is required return zero rows.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Assertion

Returns a new instance of Assertion.



189
190
191
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dependency_targetsArray<Google::Apis::DataformV1beta1::Target>

A list of actions that this action depends on. Corresponds to the JSON property dependencyTargets



159
160
161
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 159

def dependency_targets
  @dependency_targets
end

#disabledBoolean Also known as: disabled?

Whether this action is disabled (i.e. should not be run). Corresponds to the JSON property disabled

Returns:

  • (Boolean)


164
165
166
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 164

def disabled
  @disabled
end

#parent_actionGoogle::Apis::DataformV1beta1::Target

Represents an action identifier. If the action writes output, the output will be written to the referenced database object. Corresponds to the JSON property parentAction



171
172
173
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 171

def parent_action
  @parent_action
end

#relation_descriptorGoogle::Apis::DataformV1beta1::RelationDescriptor

Describes a relation and its columns. Corresponds to the JSON property relationDescriptor



176
177
178
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 176

def relation_descriptor
  @relation_descriptor
end

#select_queryString

The SELECT query which must return zero rows in order for this assertion to succeed. Corresponds to the JSON property selectQuery

Returns:

  • (String)


182
183
184
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 182

def select_query
  @select_query
end

#tagsArray<String>

Arbitrary, user-defined tags on this action. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


187
188
189
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 187

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



194
195
196
197
198
199
200
201
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 194

def update!(**args)
  @dependency_targets = args[:dependency_targets] if args.key?(:dependency_targets)
  @disabled = args[:disabled] if args.key?(:disabled)
  @parent_action = args[:parent_action] if args.key?(:parent_action)
  @relation_descriptor = args[:relation_descriptor] if args.key?(:relation_descriptor)
  @select_query = args[:select_query] if args.key?(:select_query)
  @tags = args[:tags] if args.key?(:tags)
end