Class: Google::Apis::DataformV1beta1::CodeCompilationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::CodeCompilationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Configures various aspects of Dataform code compilation.
Instance Attribute Summary collapse
-
#assertion_schema ⇒ String
Optional.
-
#builtin_assertion_name_prefix ⇒ String
Optional.
-
#database_suffix ⇒ String
Optional.
-
#default_database ⇒ String
Optional.
-
#default_location ⇒ String
Optional.
-
#default_notebook_runtime_options ⇒ Google::Apis::DataformV1beta1::NotebookRuntimeOptions
Configures various aspects of Dataform notebook runtime.
-
#default_schema ⇒ String
Optional.
-
#pipeline_config ⇒ Google::Apis::DataformV1beta1::PipelineConfig
Defines the pipeline type and path within the Git repository.
-
#schema_suffix ⇒ String
Optional.
-
#table_prefix ⇒ String
Optional.
-
#vars ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CodeCompilationConfig
constructor
A new instance of CodeCompilationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CodeCompilationConfig
Returns a new instance of CodeCompilationConfig.
497 498 499 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assertion_schema ⇒ String
Optional. The default schema (BigQuery dataset ID) for assertions.
Corresponds to the JSON property assertionSchema
440 441 442 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 440 def assertion_schema @assertion_schema end |
#builtin_assertion_name_prefix ⇒ String
Optional. The prefix to prepend to built-in assertion names.
Corresponds to the JSON property builtinAssertionNamePrefix
445 446 447 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 445 def builtin_assertion_name_prefix @builtin_assertion_name_prefix end |
#database_suffix ⇒ String
Optional. The suffix that should be appended to all database (Google Cloud
project ID) names.
Corresponds to the JSON property databaseSuffix
451 452 453 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 451 def database_suffix @database_suffix end |
#default_database ⇒ String
Optional. The default database (Google Cloud project ID).
Corresponds to the JSON property defaultDatabase
456 457 458 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 456 def default_database @default_database end |
#default_location ⇒ String
Optional. The default BigQuery location to use. Defaults to "US". See the
BigQuery docs for a full list of locations: https://cloud.google.com/bigquery/
docs/locations.
Corresponds to the JSON property defaultLocation
463 464 465 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 463 def default_location @default_location end |
#default_notebook_runtime_options ⇒ Google::Apis::DataformV1beta1::NotebookRuntimeOptions
Configures various aspects of Dataform notebook runtime.
Corresponds to the JSON property defaultNotebookRuntimeOptions
468 469 470 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 468 def @default_notebook_runtime_options end |
#default_schema ⇒ String
Optional. The default schema (BigQuery dataset ID).
Corresponds to the JSON property defaultSchema
473 474 475 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 473 def default_schema @default_schema end |
#pipeline_config ⇒ Google::Apis::DataformV1beta1::PipelineConfig
Defines the pipeline type and path within the Git repository.
Corresponds to the JSON property pipelineConfig
478 479 480 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 478 def pipeline_config @pipeline_config end |
#schema_suffix ⇒ String
Optional. The suffix that should be appended to all schema (BigQuery dataset
ID) names.
Corresponds to the JSON property schemaSuffix
484 485 486 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 484 def schema_suffix @schema_suffix end |
#table_prefix ⇒ String
Optional. The prefix that should be prepended to all table names.
Corresponds to the JSON property tablePrefix
489 490 491 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 489 def table_prefix @table_prefix end |
#vars ⇒ Hash<String,String>
Optional. User-defined variables that are made available to project code
during compilation.
Corresponds to the JSON property vars
495 496 497 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 495 def vars @vars end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
502 503 504 505 506 507 508 509 510 511 512 513 514 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 502 def update!(**args) @assertion_schema = args[:assertion_schema] if args.key?(:assertion_schema) @builtin_assertion_name_prefix = args[:builtin_assertion_name_prefix] if args.key?(:builtin_assertion_name_prefix) @database_suffix = args[:database_suffix] if args.key?(:database_suffix) @default_database = args[:default_database] if args.key?(:default_database) @default_location = args[:default_location] if args.key?(:default_location) @default_notebook_runtime_options = args[:default_notebook_runtime_options] if args.key?(:default_notebook_runtime_options) @default_schema = args[:default_schema] if args.key?(:default_schema) @pipeline_config = args[:pipeline_config] if args.key?(:pipeline_config) @schema_suffix = args[:schema_suffix] if args.key?(:schema_suffix) @table_prefix = args[:table_prefix] if args.key?(:table_prefix) @vars = args[:vars] if args.key?(:vars) end |