Class: Google::Apis::DataformV1beta1::ColumnDescriptor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Describes a column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ColumnDescriptor

Returns a new instance of ColumnDescriptor.



474
475
476
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_policy_tagsArray<String>

A list of BigQuery policy tags that will be applied to the column. Corresponds to the JSON property bigqueryPolicyTags

Returns:

  • (Array<String>)


461
462
463
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 461

def bigquery_policy_tags
  @bigquery_policy_tags
end

#descriptionString

A textual description of the column. Corresponds to the JSON property description

Returns:

  • (String)


466
467
468
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 466

def description
  @description
end

#pathArray<String>

The identifier for the column. Each entry in path represents one level of nesting. Corresponds to the JSON property path

Returns:

  • (Array<String>)


472
473
474
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 472

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



479
480
481
482
483
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 479

def update!(**args)
  @bigquery_policy_tags = args[:bigquery_policy_tags] if args.key?(:bigquery_policy_tags)
  @description = args[:description] if args.key?(:description)
  @path = args[:path] if args.key?(:path)
end