Class: Google::Apis::DataformV1beta1::CompilationResult
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::CompilationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents the result of compiling a Dataform project.
Instance Attribute Summary collapse
-
#code_compilation_config ⇒ Google::Apis::DataformV1beta1::CodeCompilationConfig
Configures various aspects of Dataform code compilation.
-
#compilation_errors ⇒ Array<Google::Apis::DataformV1beta1::CompilationError>
Output only.
-
#create_time ⇒ String
Output only.
-
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
-
#dataform_core_version ⇒ String
Output only.
-
#gcs_repository_snapshot_metadata ⇒ Google::Apis::DataformV1beta1::GcsRepositorySnapshotMetadata
Metadata about a repository snapshot stored in Google Cloud Storage.
-
#git_commitish ⇒ String
Immutable.
-
#internal_metadata ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#private_resource_metadata ⇒ Google::Apis::DataformV1beta1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
-
#release_config ⇒ String
Immutable.
-
#resolved_git_commit_sha ⇒ String
Output only.
-
#workspace ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompilationResult
constructor
A new instance of CompilationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompilationResult
Returns a new instance of CompilationResult.
849 850 851 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_compilation_config ⇒ Google::Apis::DataformV1beta1::CodeCompilationConfig
Configures various aspects of Dataform code compilation.
Corresponds to the JSON property codeCompilationConfig
780 781 782 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 780 def code_compilation_config @code_compilation_config end |
#compilation_errors ⇒ Array<Google::Apis::DataformV1beta1::CompilationError>
Output only. Errors encountered during project compilation.
Corresponds to the JSON property compilationErrors
785 786 787 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 785 def compilation_errors @compilation_errors end |
#create_time ⇒ String
Output only. The timestamp of when the compilation result was created.
Corresponds to the JSON property createTime
790 791 792 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 790 def create_time @create_time end |
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
Corresponds to the JSON property dataEncryptionState
795 796 797 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 795 def data_encryption_state @data_encryption_state end |
#dataform_core_version ⇒ String
Output only. The version of @dataform/core that was used for compilation.
Corresponds to the JSON property dataformCoreVersion
800 801 802 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 800 def dataform_core_version @dataform_core_version end |
#gcs_repository_snapshot_metadata ⇒ Google::Apis::DataformV1beta1::GcsRepositorySnapshotMetadata
Metadata about a repository snapshot stored in Google Cloud Storage.
Corresponds to the JSON property gcsRepositorySnapshotMetadata
805 806 807 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 805 def @gcs_repository_snapshot_metadata end |
#git_commitish ⇒ String
Immutable. Git commit/tag/branch name at which the repository should be
compiled. Must exist in the remote repository. Examples: - a commit SHA:
12ade345 - a tag: tag1 - a branch name: branch1
Corresponds to the JSON property gitCommitish
812 813 814 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 812 def git_commitish @git_commitish end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
819 820 821 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 819 def @internal_metadata end |
#name ⇒ String
Output only. The compilation result's name.
Corresponds to the JSON property name
824 825 826 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 824 def name @name end |
#private_resource_metadata ⇒ Google::Apis::DataformV1beta1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
Corresponds to the JSON property privateResourceMetadata
829 830 831 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 829 def @private_resource_metadata end |
#release_config ⇒ String
Immutable. The name of the release config to compile. Must be in the format
projects/*/locations/*/repositories/*/releaseConfigs/*.
Corresponds to the JSON property releaseConfig
835 836 837 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 835 def release_config @release_config end |
#resolved_git_commit_sha ⇒ String
Output only. The fully resolved Git commit SHA of the code that was compiled.
Not set for compilation results whose source is a workspace.
Corresponds to the JSON property resolvedGitCommitSha
841 842 843 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 841 def resolved_git_commit_sha @resolved_git_commit_sha end |
#workspace ⇒ String
Immutable. The name of the workspace to compile. Must be in the format
projects/*/locations/*/repositories/*/workspaces/*.
Corresponds to the JSON property workspace
847 848 849 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 847 def workspace @workspace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 854 def update!(**args) @code_compilation_config = args[:code_compilation_config] if args.key?(:code_compilation_config) @compilation_errors = args[:compilation_errors] if args.key?(:compilation_errors) @create_time = args[:create_time] if args.key?(:create_time) @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state) @dataform_core_version = args[:dataform_core_version] if args.key?(:dataform_core_version) @gcs_repository_snapshot_metadata = args[:gcs_repository_snapshot_metadata] if args.key?(:gcs_repository_snapshot_metadata) @git_commitish = args[:git_commitish] if args.key?(:git_commitish) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @name = args[:name] if args.key?(:name) @private_resource_metadata = args[:private_resource_metadata] if args.key?(:private_resource_metadata) @release_config = args[:release_config] if args.key?(:release_config) @resolved_git_commit_sha = args[:resolved_git_commit_sha] if args.key?(:resolved_git_commit_sha) @workspace = args[:workspace] if args.key?(:workspace) end |