Class: Google::Apis::DataformV1beta1::CompilationResultAction
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::CompilationResultAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a single Dataform action in a compilation result.
Instance Attribute Summary collapse
-
#assertion ⇒ Google::Apis::DataformV1beta1::Assertion
Represents an assertion upon a SQL query which is required return zero rows.
-
#canonical_target ⇒ Google::Apis::DataformV1beta1::Target
Represents an action identifier.
-
#data_preparation ⇒ Google::Apis::DataformV1beta1::DataPreparation
Defines a compiled Data Preparation entity Corresponds to the JSON property
dataPreparation. -
#declaration ⇒ Google::Apis::DataformV1beta1::Declaration
Represents a relation which is not managed by Dataform but which may be referenced by Dataform actions.
-
#file_path ⇒ String
The full path including filename in which this action is located, relative to the workspace root.
-
#internal_metadata ⇒ String
Output only.
-
#notebook ⇒ Google::Apis::DataformV1beta1::Notebook
Represents a notebook.
-
#operations ⇒ Google::Apis::DataformV1beta1::Operations
Represents a list of arbitrary database operations.
-
#relation ⇒ Google::Apis::DataformV1beta1::Relation
Represents a database relation.
-
#target ⇒ Google::Apis::DataformV1beta1::Target
Represents an action identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompilationResultAction
constructor
A new instance of CompilationResultAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompilationResultAction
Returns a new instance of CompilationResultAction.
931 932 933 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assertion ⇒ Google::Apis::DataformV1beta1::Assertion
Represents an assertion upon a SQL query which is required return zero rows.
Corresponds to the JSON property assertion
878 879 880 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 878 def assertion @assertion end |
#canonical_target ⇒ Google::Apis::DataformV1beta1::Target
Represents an action identifier. If the action writes output, the output will
be written to the referenced database object.
Corresponds to the JSON property canonicalTarget
884 885 886 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 884 def canonical_target @canonical_target end |
#data_preparation ⇒ Google::Apis::DataformV1beta1::DataPreparation
Defines a compiled Data Preparation entity
Corresponds to the JSON property dataPreparation
889 890 891 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 889 def data_preparation @data_preparation end |
#declaration ⇒ Google::Apis::DataformV1beta1::Declaration
Represents a relation which is not managed by Dataform but which may be
referenced by Dataform actions.
Corresponds to the JSON property declaration
895 896 897 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 895 def declaration @declaration end |
#file_path ⇒ String
The full path including filename in which this action is located, relative to
the workspace root.
Corresponds to the JSON property filePath
901 902 903 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 901 def file_path @file_path end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
908 909 910 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 908 def @internal_metadata end |
#notebook ⇒ Google::Apis::DataformV1beta1::Notebook
Represents a notebook.
Corresponds to the JSON property notebook
913 914 915 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 913 def notebook @notebook end |
#operations ⇒ Google::Apis::DataformV1beta1::Operations
Represents a list of arbitrary database operations.
Corresponds to the JSON property operations
918 919 920 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 918 def operations @operations end |
#relation ⇒ Google::Apis::DataformV1beta1::Relation
Represents a database relation.
Corresponds to the JSON property relation
923 924 925 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 923 def relation @relation end |
#target ⇒ Google::Apis::DataformV1beta1::Target
Represents an action identifier. If the action writes output, the output will
be written to the referenced database object.
Corresponds to the JSON property target
929 930 931 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 929 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
936 937 938 939 940 941 942 943 944 945 946 947 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 936 def update!(**args) @assertion = args[:assertion] if args.key?(:assertion) @canonical_target = args[:canonical_target] if args.key?(:canonical_target) @data_preparation = args[:data_preparation] if args.key?(:data_preparation) @declaration = args[:declaration] if args.key?(:declaration) @file_path = args[:file_path] if args.key?(:file_path) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @notebook = args[:notebook] if args.key?(:notebook) @operations = args[:operations] if args.key?(:operations) @relation = args[:relation] if args.key?(:relation) @target = args[:target] if args.key?(:target) end |