Class: Google::Apis::DataformV1beta1::Config
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::Config
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Config for all repositories in a given project and location.
Instance Attribute Summary collapse
-
#default_kms_key_name ⇒ String
Optional.
-
#internal_metadata ⇒ String
Output only.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Config
constructor
A new instance of Config.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Config
Returns a new instance of Config.
916 917 918 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_kms_key_name ⇒ String
Optional. The default KMS key that is used if no encryption key is provided
when a repository is created.
Corresponds to the JSON property defaultKmsKeyName
902 903 904 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 902 def default_kms_key_name @default_kms_key_name end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
909 910 911 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 909 def @internal_metadata end |
#name ⇒ String
Identifier. The config name.
Corresponds to the JSON property name
914 915 916 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 914 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
921 922 923 924 925 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 921 def update!(**args) @default_kms_key_name = args[:default_kms_key_name] if args.key?(:default_kms_key_name) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @name = args[:name] if args.key?(:name) end |