Class: Google::Apis::DataformV1beta1::DataPreparationAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a workflow action that will run a Data Preparation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataPreparationAction

Returns a new instance of DataPreparationAction.



1093
1094
1095
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contents_sqlGoogle::Apis::DataformV1beta1::ActionSqlDefinition

Definition of a SQL Data Preparation Corresponds to the JSON property contentsSql



1073
1074
1075
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1073

def contents_sql
  @contents_sql
end

#contents_yamlString

Output only. YAML representing the contents of the data preparation. Can be used to show the customer what the input was to their workflow. Corresponds to the JSON property contentsYaml

Returns:

  • (String)


1079
1080
1081
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1079

def contents_yaml
  @contents_yaml
end

#generated_sqlString

Output only. The generated BigQuery SQL script that will be executed. For reference only. Corresponds to the JSON property generatedSql

Returns:

  • (String)


1085
1086
1087
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1085

def generated_sql
  @generated_sql
end

#job_idString

Output only. The ID of the BigQuery job that executed the SQL in sql_script. Only set once the job has started to run. Corresponds to the JSON property jobId

Returns:

  • (String)


1091
1092
1093
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1091

def job_id
  @job_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1098
1099
1100
1101
1102
1103
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1098

def update!(**args)
  @contents_sql = args[:contents_sql] if args.key?(:contents_sql)
  @contents_yaml = args[:contents_yaml] if args.key?(:contents_yaml)
  @generated_sql = args[:generated_sql] if args.key?(:generated_sql)
  @job_id = args[:job_id] if args.key?(:job_id)
end