Class: Google::Apis::DataformV1beta1::DeleteRepositoryLongRunningRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

DeleteRepositoryLongRunning request message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteRepositoryLongRunningRequest

Returns a new instance of DeleteRepositoryLongRunningRequest.



1218
1219
1220
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

Optional. If set to true, child resources of this repository (compilation results and workflow invocations) will also be deleted. Otherwise, the request will only succeed if the repository has no child resources. Note: This flag doesn't support deletion of workspaces, release configs or workflow configs. If any of such resources exists in the repository, the request will fail. Corresponds to the JSON property force

Returns:

  • (Boolean)


1215
1216
1217
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1215

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1223
1224
1225
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1223

def update!(**args)
  @force = args[:force] if args.key?(:force)
end