Class: Google::Apis::DataformV1beta1::DirectoryEntry
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::DirectoryEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a single entry in a directory.
Instance Attribute Summary collapse
-
#directory ⇒ String
A child directory in the directory.
-
#file ⇒ String
A file in the directory.
-
#metadata ⇒ Google::Apis::DataformV1beta1::FilesystemEntryMetadata
Represents metadata for a single entry in a filesystem.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DirectoryEntry
constructor
A new instance of DirectoryEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DirectoryEntry
Returns a new instance of DirectoryEntry.
1273 1274 1275 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1273 def initialize(**args) update!(**args) end |
Instance Attribute Details
#directory ⇒ String
A child directory in the directory. The path is returned including the full
folder structure from the root.
Corresponds to the JSON property directory
1260 1261 1262 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1260 def directory @directory end |
#file ⇒ String
A file in the directory. The path is returned including the full folder
structure from the root.
Corresponds to the JSON property file
1266 1267 1268 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1266 def file @file end |
#metadata ⇒ Google::Apis::DataformV1beta1::FilesystemEntryMetadata
Represents metadata for a single entry in a filesystem.
Corresponds to the JSON property metadata
1271 1272 1273 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1271 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1278 1279 1280 1281 1282 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1278 def update!(**args) @directory = args[:directory] if args.key?(:directory) @file = args[:file] if args.key?(:file) @metadata = args[:metadata] if args.key?(:metadata) end |