Class: Google::Apis::DataformV1beta1::ErrorTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Error table information, used to write error data into a BigQuery table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ErrorTable

Returns a new instance of ErrorTable.



1220
1221
1222
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1220

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#retention_daysFixnum

Error table partition expiration in days. Only positive values are allowed. Corresponds to the JSON property retentionDays

Returns:

  • (Fixnum)


1212
1213
1214
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1212

def retention_days
  @retention_days
end

#targetGoogle::Apis::DataformV1beta1::Target

Represents an action identifier. If the action writes output, the output will be written to the referenced database object. Corresponds to the JSON property target



1218
1219
1220
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1218

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1225
1226
1227
1228
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1225

def update!(**args)
  @retention_days = args[:retention_days] if args.key?(:retention_days)
  @target = args[:target] if args.key?(:target)
end