Class: Google::Apis::DataformV1beta1::FetchCurrentWorkspaceBranchResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::FetchCurrentWorkspaceBranchResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Response message for FetchCurrentWorkspaceBranch method.
Instance Attribute Summary collapse
-
#branch_name ⇒ String
The name of the current branch for the workspace.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchCurrentWorkspaceBranchResponse
constructor
A new instance of FetchCurrentWorkspaceBranchResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchCurrentWorkspaceBranchResponse
Returns a new instance of FetchCurrentWorkspaceBranchResponse.
1409 1410 1411 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#branch_name ⇒ String
The name of the current branch for the workspace.
Corresponds to the JSON property branchName
1407 1408 1409 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1407 def branch_name @branch_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1414 1415 1416 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1414 def update!(**args) @branch_name = args[:branch_name] if args.key?(:branch_name) end |