Class: Google::Apis::DataformV1beta1::FilesystemEntryMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents metadata for a single entry in a filesystem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FilesystemEntryMetadata

Returns a new instance of FilesystemEntryMetadata.



1613
1614
1615
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#size_bytesFixnum

Output only. Provides the size of the entry in bytes. For directories, this will be 0. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


1606
1607
1608
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1606

def size_bytes
  @size_bytes
end

#update_timeString

Output only. Represents the time of the last modification of the entry. Corresponds to the JSON property updateTime

Returns:

  • (String)


1611
1612
1613
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1611

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1618
1619
1620
1621
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1618

def update!(**args)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @update_time = args[:update_time] if args.key?(:update_time)
end