Class: Google::Apis::DataformV1beta1::Folder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a Dataform Folder. This is a resource that is used to organize Files and other Folders and provide hierarchical access controls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Folder

Returns a new instance of Folder.



1677
1678
1679
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containing_folderString

Optional. The containing Folder resource name. This should take the format: projects/project/locations/location/folders/folder, projects/project/ locations/location/teamFolders/teamFolder, or just "" if this is a root Folder. This field can only be updated through MoveFolder. Corresponds to the JSON property containingFolder

Returns:

  • (String)


1635
1636
1637
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1635

def containing_folder
  @containing_folder
end

#create_timeString

Output only. The timestamp of when the Folder was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1640
1641
1642
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1640

def create_time
  @create_time
end

#creator_iam_principalString

Output only. The IAM principal identifier of the creator of the Folder. Corresponds to the JSON property creatorIamPrincipal

Returns:

  • (String)


1645
1646
1647
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1645

def creator_iam_principal
  @creator_iam_principal
end

#display_nameString

Required. The Folder's user-friendly name. Corresponds to the JSON property displayName

Returns:

  • (String)


1650
1651
1652
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1650

def display_name
  @display_name
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


1657
1658
1659
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1657

def 
  @internal_metadata
end

#nameString

Identifier. The Folder's name. Corresponds to the JSON property name

Returns:

  • (String)


1662
1663
1664
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1662

def name
  @name
end

#team_folder_nameString

Output only. The resource name of the TeamFolder that this Folder is associated with. This should take the format: projects/project/locations/ location/teamFolders/teamFolder. If this is not set, the Folder is not associated with a TeamFolder and is a UserFolder. Corresponds to the JSON property teamFolderName

Returns:

  • (String)


1670
1671
1672
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1670

def team_folder_name
  @team_folder_name
end

#update_timeString

Output only. The timestamp of when the Folder was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1675
1676
1677
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1675

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1682

def update!(**args)
  @containing_folder = args[:containing_folder] if args.key?(:containing_folder)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator_iam_principal = args[:creator_iam_principal] if args.key?(:creator_iam_principal)
  @display_name = args[:display_name] if args.key?(:display_name)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @name = args[:name] if args.key?(:name)
  @team_folder_name = args[:team_folder_name] if args.key?(:team_folder_name)
  @update_time = args[:update_time] if args.key?(:update_time)
end