Class: Google::Apis::DataformV1beta1::FolderContentsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a single content entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FolderContentsEntry

Returns a new instance of FolderContentsEntry.



1522
1523
1524
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folderGoogle::Apis::DataformV1beta1::Folder

Represents a Dataform Folder. This is a resource that is used to organize Files and other Folders and provide hierarchical access controls. Corresponds to the JSON property folder



1515
1516
1517
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1515

def folder
  @folder
end

#repositoryGoogle::Apis::DataformV1beta1::Repository

Represents a Dataform Git repository. Corresponds to the JSON property repository



1520
1521
1522
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1520

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1527
1528
1529
1530
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1527

def update!(**args)
  @folder = args[:folder] if args.key?(:folder)
  @repository = args[:repository] if args.key?(:repository)
end