Class: Google::Apis::DataformV1beta1::InstallNpmPackagesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::InstallNpmPackagesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
InstallNpmPackages request message.
Instance Attribute Summary collapse
-
#pipeline_config ⇒ Google::Apis::DataformV1beta1::PipelineConfig
Defines the pipeline type and path within the Git repository.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstallNpmPackagesRequest
constructor
A new instance of InstallNpmPackagesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstallNpmPackagesRequest
Returns a new instance of InstallNpmPackagesRequest.
1802 1803 1804 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1802 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pipeline_config ⇒ Google::Apis::DataformV1beta1::PipelineConfig
Defines the pipeline type and path within the Git repository.
Corresponds to the JSON property pipelineConfig
1800 1801 1802 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1800 def pipeline_config @pipeline_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1807 1808 1809 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1807 def update!(**args) @pipeline_config = args[:pipeline_config] if args.key?(:pipeline_config) end |