Class: Google::Apis::DataformV1beta1::Interval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Interval

Returns a new instance of Interval.



1992
1993
1994
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Optional. Exclusive end of the interval. If specified, a Timestamp matching this interval will have to be before the end. Corresponds to the JSON property endTime

Returns:

  • (String)


1984
1985
1986
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1984

def end_time
  @end_time
end

#start_timeString

Optional. Inclusive start of the interval. If specified, a Timestamp matching this interval will have to be the same or after the start. Corresponds to the JSON property startTime

Returns:

  • (String)


1990
1991
1992
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1990

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1997
1998
1999
2000
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1997

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end