Class: Google::Apis::DataformV1beta1::LoadConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::LoadConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Simplified load configuration for actions
Instance Attribute Summary collapse
-
#append ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition Corresponds to the JSON property
append. -
#maximum ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes Corresponds to the JSON property
maximum. -
#replace ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition Corresponds to the JSON property
replace. -
#unique ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes Corresponds to the JSON property
unique.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadConfig
constructor
A new instance of LoadConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadConfig
Returns a new instance of LoadConfig.
2193 2194 2195 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2193 def initialize(**args) update!(**args) end |
Instance Attribute Details
#append ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition
Corresponds to the JSON property append
2176 2177 2178 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2176 def append @append end |
#maximum ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes
Corresponds to the JSON property maximum
2181 2182 2183 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2181 def maximum @maximum end |
#replace ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition
Corresponds to the JSON property replace
2186 2187 2188 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2186 def replace @replace end |
#unique ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes
Corresponds to the JSON property unique
2191 2192 2193 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2191 def unique @unique end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2198 2199 2200 2201 2202 2203 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2198 def update!(**args) @append = args[:append] if args.key?(:append) @maximum = args[:maximum] if args.key?(:maximum) @replace = args[:replace] if args.key?(:replace) @unique = args[:unique] if args.key?(:unique) end |