Class: Google::Apis::DataformV1beta1::MoveDirectoryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

MoveDirectory request message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MoveDirectoryRequest

Returns a new instance of MoveDirectoryRequest.



2224
2225
2226
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_pathString

Required. The new path for the directory including directory name, rooted at workspace root. Corresponds to the JSON property newPath

Returns:

  • (String)


2216
2217
2218
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2216

def new_path
  @new_path
end

#pathString

Required. The directory's full path including directory name, relative to the workspace root. Corresponds to the JSON property path

Returns:

  • (String)


2222
2223
2224
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2222

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2229
2230
2231
2232
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2229

def update!(**args)
  @new_path = args[:new_path] if args.key?(:new_path)
  @path = args[:path] if args.key?(:path)
end