Class: Google::Apis::DataformV1beta1::MoveFileRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

MoveFile request message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MoveFileRequest

Returns a new instance of MoveFileRequest.



2264
2265
2266
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_pathString

Required. The file's new path including filename, relative to the workspace root. Corresponds to the JSON property newPath

Returns:

  • (String)


2256
2257
2258
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2256

def new_path
  @new_path
end

#pathString

Required. The file's full path including filename, relative to the workspace root. Corresponds to the JSON property path

Returns:

  • (String)


2262
2263
2264
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2262

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2269
2270
2271
2272
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2269

def update!(**args)
  @new_path = args[:new_path] if args.key?(:new_path)
  @path = args[:path] if args.key?(:path)
end