Class: Google::Apis::DataformV1beta1::Notebook
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::Notebook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a notebook.
Instance Attribute Summary collapse
-
#contents ⇒ String
The contents of the notebook.
-
#dependency_targets ⇒ Array<Google::Apis::DataformV1beta1::Target>
A list of actions that this action depends on.
-
#disabled ⇒ Boolean
(also: #disabled?)
Whether this action is disabled (i.e. should not be run).
-
#tags ⇒ Array<String>
Arbitrary, user-defined tags on this action.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Notebook
constructor
A new instance of Notebook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Notebook
Returns a new instance of Notebook.
2581 2582 2583 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2581 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
The contents of the notebook.
Corresponds to the JSON property contents
2563 2564 2565 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2563 def contents @contents end |
#dependency_targets ⇒ Array<Google::Apis::DataformV1beta1::Target>
A list of actions that this action depends on.
Corresponds to the JSON property dependencyTargets
2568 2569 2570 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2568 def dependency_targets @dependency_targets end |
#disabled ⇒ Boolean Also known as: disabled?
Whether this action is disabled (i.e. should not be run).
Corresponds to the JSON property disabled
2573 2574 2575 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2573 def disabled @disabled end |
#tags ⇒ Array<String>
Arbitrary, user-defined tags on this action.
Corresponds to the JSON property tags
2579 2580 2581 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2579 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2586 2587 2588 2589 2590 2591 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2586 def update!(**args) @contents = args[:contents] if args.key?(:contents) @dependency_targets = args[:dependency_targets] if args.key?(:dependency_targets) @disabled = args[:disabled] if args.key?(:disabled) @tags = args[:tags] if args.key?(:tags) end |