Class: Google::Apis::DataformV1beta1::NotebookRuntimeOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Configures various aspects of Dataform notebook runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotebookRuntimeOptions

Returns a new instance of NotebookRuntimeOptions.



2650
2651
2652
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_platform_notebook_runtime_templateString

Optional. The resource name of the Colab runtime template, from which a runtime is created for notebook executions. If not specified, a runtime is created with Colab's default specifications. Corresponds to the JSON property aiPlatformNotebookRuntimeTemplate

Returns:

  • (String)


2637
2638
2639
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2637

def ai_platform_notebook_runtime_template
  @ai_platform_notebook_runtime_template
end

#gcs_output_bucketString

Optional. The Google Cloud Storage location to upload the result to. Format: gs://bucket-name. Corresponds to the JSON property gcsOutputBucket

Returns:

  • (String)


2643
2644
2645
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2643

def gcs_output_bucket
  @gcs_output_bucket
end

#gcs_repository_snapshot_destinationGoogle::Apis::DataformV1beta1::GcsRepositorySnapshotDestination

Configures the destination for a repository snapshot. Corresponds to the JSON property gcsRepositorySnapshotDestination



2648
2649
2650
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2648

def gcs_repository_snapshot_destination
  @gcs_repository_snapshot_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2655
2656
2657
2658
2659
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2655

def update!(**args)
  @ai_platform_notebook_runtime_template = args[:ai_platform_notebook_runtime_template] if args.key?(:ai_platform_notebook_runtime_template)
  @gcs_output_bucket = args[:gcs_output_bucket] if args.key?(:gcs_output_bucket)
  @gcs_repository_snapshot_destination = args[:gcs_repository_snapshot_destination] if args.key?(:gcs_repository_snapshot_destination)
end