Class: Google::Apis::DataformV1beta1::PipelineConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Defines the pipeline type and path within the Git repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PipelineConfig

Returns a new instance of PipelineConfig.



2850
2851
2852
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pathString

Required. The relative path within the Git repository where the pipeline is defined. For example, for a Dataform pipeline, it is a path to the folder where workflow_settings.yaml or dataform.json is located. Corresponds to the JSON property path

Returns:

  • (String)


2843
2844
2845
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2843

def path
  @path
end

#pipeline_typeString

Required. The type of the pipeline. Corresponds to the JSON property pipelineType

Returns:

  • (String)


2848
2849
2850
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2848

def pipeline_type
  @pipeline_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2855
2856
2857
2858
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2855

def update!(**args)
  @path = args[:path] if args.key?(:path)
  @pipeline_type = args[:pipeline_type] if args.key?(:pipeline_type)
end