Class: Google::Apis::DataformV1beta1::RelationDescriptor
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::RelationDescriptor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Describes a relation and its columns.
Instance Attribute Summary collapse
-
#bigquery_labels ⇒ Hash<String,String>
A set of BigQuery labels that should be applied to the relation.
-
#columns ⇒ Array<Google::Apis::DataformV1beta1::ColumnDescriptor>
A list of descriptions of columns within the relation.
-
#description ⇒ String
A text description of the relation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RelationDescriptor
constructor
A new instance of RelationDescriptor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RelationDescriptor
Returns a new instance of RelationDescriptor.
3199 3200 3201 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_labels ⇒ Hash<String,String>
A set of BigQuery labels that should be applied to the relation.
Corresponds to the JSON property bigqueryLabels
3187 3188 3189 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3187 def bigquery_labels @bigquery_labels end |
#columns ⇒ Array<Google::Apis::DataformV1beta1::ColumnDescriptor>
A list of descriptions of columns within the relation.
Corresponds to the JSON property columns
3192 3193 3194 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3192 def columns @columns end |
#description ⇒ String
A text description of the relation.
Corresponds to the JSON property description
3197 3198 3199 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3197 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3204 3205 3206 3207 3208 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3204 def update!(**args) @bigquery_labels = args[:bigquery_labels] if args.key?(:bigquery_labels) @columns = args[:columns] if args.key?(:columns) @description = args[:description] if args.key?(:description) end |