Class: Google::Apis::DataformV1beta1::RootContentsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a single content entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RootContentsEntry

Returns a new instance of RootContentsEntry.



3536
3537
3538
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folderGoogle::Apis::DataformV1beta1::Folder

Represents a Dataform Folder. This is a resource that is used to organize Files and other Folders and provide hierarchical access controls. Corresponds to the JSON property folder



3529
3530
3531
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3529

def folder
  @folder
end

#repositoryGoogle::Apis::DataformV1beta1::Repository

Represents a Dataform Git repository. Corresponds to the JSON property repository



3534
3535
3536
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3534

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3541
3542
3543
3544
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3541

def update!(**args)
  @folder = args[:folder] if args.key?(:folder)
  @repository = args[:repository] if args.key?(:repository)
end