Class: Google::Apis::DataformV1beta1::SqlDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Definition of a SQL Data Preparation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlDefinition

Returns a new instance of SqlDefinition.



3890
3891
3892
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3890

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_tableGoogle::Apis::DataformV1beta1::ErrorTable

Error table information, used to write error data into a BigQuery table. Corresponds to the JSON property errorTable



3877
3878
3879
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3877

def error_table
  @error_table
end

#loadGoogle::Apis::DataformV1beta1::LoadConfig

Simplified load configuration for actions Corresponds to the JSON property load



3882
3883
3884
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3882

def load
  @load
end

#queryString

The SQL query representing the data preparation steps. Formatted as a Pipe SQL query statement. Corresponds to the JSON property query

Returns:

  • (String)


3888
3889
3890
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3888

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3895
3896
3897
3898
3899
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3895

def update!(**args)
  @error_table = args[:error_table] if args.key?(:error_table)
  @load = args[:load] if args.key?(:load)
  @query = args[:query] if args.key?(:query)
end