Class: Google::Apis::DataformV1beta1::SyncWorkspaceRefsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

SyncWorkspaceRefs request message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SyncWorkspaceRefsRequest

Returns a new instance of SyncWorkspaceRefsRequest.



4134
4135
4136
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deepenFixnum

Optional. Can be used to deepen the commit history of shallow clones. Git documentation: https://git-scm.com/docs/git-fetch#Documentation/git-fetch.txt-- -deependepth Corresponds to the JSON property deepen

Returns:

  • (Fixnum)


4126
4127
4128
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4126

def deepen
  @deepen
end

#remote_branch_nameString

Optional. The name of the branch in the Git remote to which the refs should be fetched for. If left unset, all remote branches will be fetched. Corresponds to the JSON property remoteBranchName

Returns:

  • (String)


4132
4133
4134
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4132

def remote_branch_name
  @remote_branch_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4139
4140
4141
4142
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4139

def update!(**args)
  @deepen = args[:deepen] if args.key?(:deepen)
  @remote_branch_name = args[:remote_branch_name] if args.key?(:remote_branch_name)
end