Class: Google::Apis::DataformV1beta1::TeamFolder
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::TeamFolder
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a Dataform TeamFolder. This is a resource that sits at the project level and is used to organize Repositories and Folders with hierarchical access controls. They provide a team context and stricter access controls.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#creator_iam_principal ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#internal_metadata ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TeamFolder
constructor
A new instance of TeamFolder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TeamFolder
Returns a new instance of TeamFolder.
4256 4257 4258 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4256 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp of when the TeamFolder was created.
Corresponds to the JSON property createTime
4227 4228 4229 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4227 def create_time @create_time end |
#creator_iam_principal ⇒ String
Output only. The IAM principal identifier of the creator of the TeamFolder.
Corresponds to the JSON property creatorIamPrincipal
4232 4233 4234 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4232 def creator_iam_principal @creator_iam_principal end |
#display_name ⇒ String
Required. The TeamFolder's user-friendly name.
Corresponds to the JSON property displayName
4237 4238 4239 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4237 def display_name @display_name end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
4244 4245 4246 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4244 def @internal_metadata end |
#name ⇒ String
Identifier. The TeamFolder's name.
Corresponds to the JSON property name
4249 4250 4251 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4249 def name @name end |
#update_time ⇒ String
Output only. The timestamp of when the TeamFolder was last updated.
Corresponds to the JSON property updateTime
4254 4255 4256 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4254 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4261 4262 4263 4264 4265 4266 4267 4268 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4261 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @creator_iam_principal = args[:creator_iam_principal] if args.key?(:creator_iam_principal) @display_name = args[:display_name] if args.key?(:display_name) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |