Class: Google::Apis::DataformV1beta1::TeamFolderSearchResult
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::TeamFolderSearchResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a single content entry.
Instance Attribute Summary collapse
-
#team_folder ⇒ Google::Apis::DataformV1beta1::TeamFolder
Represents a Dataform TeamFolder.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TeamFolderSearchResult
constructor
A new instance of TeamFolderSearchResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TeamFolderSearchResult
Returns a new instance of TeamFolderSearchResult.
3938 3939 3940 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3938 def initialize(**args) update!(**args) end |
Instance Attribute Details
#team_folder ⇒ Google::Apis::DataformV1beta1::TeamFolder
Represents a Dataform TeamFolder. This is a resource that sits at the project
level and is used to organize Repositories and Folders with hierarchical
access controls. They provide a team context and stricter access controls.
Corresponds to the JSON property teamFolder
3936 3937 3938 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3936 def team_folder @team_folder end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3943 3944 3945 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3943 def update!(**args) @team_folder = args[:team_folder] if args.key?(:team_folder) end |