Class: Google::Apis::DataformV1beta1::WorkflowTriggerConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a trigger configuration for a workflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkflowTriggerConfig

Returns a new instance of WorkflowTriggerConfig.



4726
4727
4728
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionString

Optional. The condition to use when triggering the workflow. Corresponds to the JSON property condition

Returns:

  • (String)


4693
4694
4695
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4693

def condition
  @condition
end

#last_successful_evaluation_timeString

Output only. The timestamp of the last successful trigger evaluation. Corresponds to the JSON property lastSuccessfulEvaluationTime

Returns:

  • (String)


4698
4699
4700
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4698

def last_successful_evaluation_time
  @last_successful_evaluation_time
end

#max_wait_durationString

Optional. The effective maximum wait time duration for the trigger condition to be met. If not specified, the workflow won't be triggered until conditions are met. Corresponds to the JSON property maxWaitDuration

Returns:

  • (String)


4705
4706
4707
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4705

def max_wait_duration
  @max_wait_duration
end

#min_execution_durationString

Optional. Minimum duration between two consecutive executions. If not specified, the workflow will be executed every time trigger conditions are met and there is no ongoing workflow execution. Corresponds to the JSON property minExecutionDuration

Returns:

  • (String)


4712
4713
4714
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4712

def min_execution_duration
  @min_execution_duration
end

#recent_trigger_evaluation_recordsArray<Google::Apis::DataformV1beta1::TriggerEvaluationRecord>

Output only. Records of the 10 most recent trigger evaluations, ordered in descending order of evaluation_time. Updated whenever the service evaluates the trigger conditions (via polling or upon receiving a push event). Corresponds to the JSON property recentTriggerEvaluationRecords



4719
4720
4721
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4719

def recent_trigger_evaluation_records
  @recent_trigger_evaluation_records
end

#workflow_triggersArray<Google::Apis::DataformV1beta1::WorkflowTrigger>

Required. The trigger definitions to invoke a workflow. Corresponds to the JSON property workflowTriggers



4724
4725
4726
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4724

def workflow_triggers
  @workflow_triggers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4731
4732
4733
4734
4735
4736
4737
4738
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4731

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @last_successful_evaluation_time = args[:last_successful_evaluation_time] if args.key?(:last_successful_evaluation_time)
  @max_wait_duration = args[:max_wait_duration] if args.key?(:max_wait_duration)
  @min_execution_duration = args[:min_execution_duration] if args.key?(:min_execution_duration)
  @recent_trigger_evaluation_records = args[:recent_trigger_evaluation_records] if args.key?(:recent_trigger_evaluation_records)
  @workflow_triggers = args[:workflow_triggers] if args.key?(:workflow_triggers)
end