Class: Google::Apis::DataformV1beta1::CheckoutWorkspaceBranchRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::CheckoutWorkspaceBranchRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
CheckoutWorkspaceBranch request message.
Instance Attribute Summary collapse
-
#branch ⇒ String
Required.
-
#create_if_not_exists ⇒ Boolean
(also: #create_if_not_exists?)
Optional.
-
#source_branch ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckoutWorkspaceBranchRequest
constructor
A new instance of CheckoutWorkspaceBranchRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckoutWorkspaceBranchRequest
Returns a new instance of CheckoutWorkspaceBranchRequest.
421 422 423 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 421 def initialize(**args) update!(**args) end |
Instance Attribute Details
#branch ⇒ String
Required. The name of the branch in the Git repository to which the workspace
should be checked out.
Corresponds to the JSON property branch
403 404 405 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 403 def branch @branch end |
#create_if_not_exists ⇒ Boolean Also known as: create_if_not_exists?
Optional. If set to true and the branch does not exist, it will be created.
Otherwise, an error will be thrown.
Corresponds to the JSON property createIfNotExists
409 410 411 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 409 def create_if_not_exists @create_if_not_exists end |
#source_branch ⇒ String
Optional. The name of the branch in the Git repository from which the new
branch should be created. If left unset, the workspace's current branch name
will be used. Accepts only branch names from FetchWorkspaceBranches response,
and can only be set if create_if_not_exists is true. Oherwise, an error will
be thrown.
Corresponds to the JSON property sourceBranch
419 420 421 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 419 def source_branch @source_branch end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
426 427 428 429 430 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 426 def update!(**args) @branch = args[:branch] if args.key?(:branch) @create_if_not_exists = args[:create_if_not_exists] if args.key?(:create_if_not_exists) @source_branch = args[:source_branch] if args.key?(:source_branch) end |