Class: Google::Apis::DataformV1beta1::CodeCompilationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Configures various aspects of Dataform code compilation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CodeCompilationConfig

Returns a new instance of CodeCompilationConfig.



429
430
431
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assertion_schemaString

Optional. The default schema (BigQuery dataset ID) for assertions. Corresponds to the JSON property assertionSchema

Returns:

  • (String)


377
378
379
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 377

def assertion_schema
  @assertion_schema
end

#builtin_assertion_name_prefixString

Optional. The prefix to prepend to built-in assertion names. Corresponds to the JSON property builtinAssertionNamePrefix

Returns:

  • (String)


382
383
384
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 382

def builtin_assertion_name_prefix
  @builtin_assertion_name_prefix
end

#database_suffixString

Optional. The suffix that should be appended to all database (Google Cloud project ID) names. Corresponds to the JSON property databaseSuffix

Returns:

  • (String)


388
389
390
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 388

def database_suffix
  @database_suffix
end

#default_databaseString

Optional. The default database (Google Cloud project ID). Corresponds to the JSON property defaultDatabase

Returns:

  • (String)


393
394
395
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 393

def default_database
  @default_database
end

#default_locationString

Optional. The default BigQuery location to use. Defaults to "US". See the BigQuery docs for a full list of locations: https://cloud.google.com/bigquery/ docs/locations. Corresponds to the JSON property defaultLocation

Returns:

  • (String)


400
401
402
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 400

def default_location
  @default_location
end

#default_notebook_runtime_optionsGoogle::Apis::DataformV1beta1::NotebookRuntimeOptions

Configures various aspects of Dataform notebook runtime. Corresponds to the JSON property defaultNotebookRuntimeOptions



405
406
407
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 405

def default_notebook_runtime_options
  @default_notebook_runtime_options
end

#default_schemaString

Optional. The default schema (BigQuery dataset ID). Corresponds to the JSON property defaultSchema

Returns:

  • (String)


410
411
412
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 410

def default_schema
  @default_schema
end

#schema_suffixString

Optional. The suffix that should be appended to all schema (BigQuery dataset ID) names. Corresponds to the JSON property schemaSuffix

Returns:

  • (String)


416
417
418
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 416

def schema_suffix
  @schema_suffix
end

#table_prefixString

Optional. The prefix that should be prepended to all table names. Corresponds to the JSON property tablePrefix

Returns:

  • (String)


421
422
423
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 421

def table_prefix
  @table_prefix
end

#varsHash<String,String>

Optional. User-defined variables that are made available to project code during compilation. Corresponds to the JSON property vars

Returns:

  • (Hash<String,String>)


427
428
429
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 427

def vars
  @vars
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 434

def update!(**args)
  @assertion_schema = args[:assertion_schema] if args.key?(:assertion_schema)
  @builtin_assertion_name_prefix = args[:builtin_assertion_name_prefix] if args.key?(:builtin_assertion_name_prefix)
  @database_suffix = args[:database_suffix] if args.key?(:database_suffix)
  @default_database = args[:default_database] if args.key?(:default_database)
  @default_location = args[:default_location] if args.key?(:default_location)
  @default_notebook_runtime_options = args[:default_notebook_runtime_options] if args.key?(:default_notebook_runtime_options)
  @default_schema = args[:default_schema] if args.key?(:default_schema)
  @schema_suffix = args[:schema_suffix] if args.key?(:schema_suffix)
  @table_prefix = args[:table_prefix] if args.key?(:table_prefix)
  @vars = args[:vars] if args.key?(:vars)
end