Class: Google::Apis::DataformV1beta1::CompilationResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents the result of compiling a Dataform project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompilationResult

Returns a new instance of CompilationResult.



786
787
788
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_compilation_configGoogle::Apis::DataformV1beta1::CodeCompilationConfig

Configures various aspects of Dataform code compilation. Corresponds to the JSON property codeCompilationConfig



717
718
719
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 717

def code_compilation_config
  @code_compilation_config
end

#compilation_errorsArray<Google::Apis::DataformV1beta1::CompilationError>

Output only. Errors encountered during project compilation. Corresponds to the JSON property compilationErrors



722
723
724
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 722

def compilation_errors
  @compilation_errors
end

#create_timeString

Output only. The timestamp of when the compilation result was created. Corresponds to the JSON property createTime

Returns:

  • (String)


727
728
729
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 727

def create_time
  @create_time
end

#data_encryption_stateGoogle::Apis::DataformV1beta1::DataEncryptionState

Describes encryption state of a resource. Corresponds to the JSON property dataEncryptionState



732
733
734
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 732

def data_encryption_state
  @data_encryption_state
end

#dataform_core_versionString

Output only. The version of @dataform/core that was used for compilation. Corresponds to the JSON property dataformCoreVersion

Returns:

  • (String)


737
738
739
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 737

def dataform_core_version
  @dataform_core_version
end

#gcs_repository_snapshot_metadataGoogle::Apis::DataformV1beta1::GcsRepositorySnapshotMetadata

Metadata about a repository snapshot stored in Google Cloud Storage. Corresponds to the JSON property gcsRepositorySnapshotMetadata



742
743
744
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 742

def 
  @gcs_repository_snapshot_metadata
end

#git_commitishString

Immutable. Git commit/tag/branch name at which the repository should be compiled. Must exist in the remote repository. Examples: - a commit SHA: 12ade345 - a tag: tag1 - a branch name: branch1 Corresponds to the JSON property gitCommitish

Returns:

  • (String)


749
750
751
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 749

def git_commitish
  @git_commitish
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


756
757
758
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 756

def 
  @internal_metadata
end

#nameString

Output only. The compilation result's name. Corresponds to the JSON property name

Returns:

  • (String)


761
762
763
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 761

def name
  @name
end

#private_resource_metadataGoogle::Apis::DataformV1beta1::PrivateResourceMetadata

Metadata used to identify if a resource is user scoped. Corresponds to the JSON property privateResourceMetadata



766
767
768
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 766

def 
  @private_resource_metadata
end

#release_configString

Immutable. The name of the release config to compile. Must be in the format projects/*/locations/*/repositories/*/releaseConfigs/*. Corresponds to the JSON property releaseConfig

Returns:

  • (String)


772
773
774
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 772

def release_config
  @release_config
end

#resolved_git_commit_shaString

Output only. The fully resolved Git commit SHA of the code that was compiled. Not set for compilation results whose source is a workspace. Corresponds to the JSON property resolvedGitCommitSha

Returns:

  • (String)


778
779
780
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 778

def resolved_git_commit_sha
  @resolved_git_commit_sha
end

#workspaceString

Immutable. The name of the workspace to compile. Must be in the format projects/*/locations/*/repositories/*/workspaces/*. Corresponds to the JSON property workspace

Returns:

  • (String)


784
785
786
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 784

def workspace
  @workspace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 791

def update!(**args)
  @code_compilation_config = args[:code_compilation_config] if args.key?(:code_compilation_config)
  @compilation_errors = args[:compilation_errors] if args.key?(:compilation_errors)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state)
  @dataform_core_version = args[:dataform_core_version] if args.key?(:dataform_core_version)
  @gcs_repository_snapshot_metadata = args[:gcs_repository_snapshot_metadata] if args.key?(:gcs_repository_snapshot_metadata)
  @git_commitish = args[:git_commitish] if args.key?(:git_commitish)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @name = args[:name] if args.key?(:name)
  @private_resource_metadata = args[:private_resource_metadata] if args.key?(:private_resource_metadata)
  @release_config = args[:release_config] if args.key?(:release_config)
  @resolved_git_commit_sha = args[:resolved_git_commit_sha] if args.key?(:resolved_git_commit_sha)
  @workspace = args[:workspace] if args.key?(:workspace)
end