Class: Google::Apis::DataformV1beta1::CompilationResult
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::CompilationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents the result of compiling a Dataform project.
Instance Attribute Summary collapse
-
#code_compilation_config ⇒ Google::Apis::DataformV1beta1::CodeCompilationConfig
Configures various aspects of Dataform code compilation.
-
#compilation_errors ⇒ Array<Google::Apis::DataformV1beta1::CompilationError>
Output only.
-
#create_time ⇒ String
Output only.
-
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
-
#dataform_core_version ⇒ String
Output only.
-
#git_commitish ⇒ String
Immutable.
-
#internal_metadata ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#private_resource_metadata ⇒ Google::Apis::DataformV1beta1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
-
#release_config ⇒ String
Immutable.
-
#resolved_git_commit_sha ⇒ String
Output only.
-
#workspace ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompilationResult
constructor
A new instance of CompilationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompilationResult
Returns a new instance of CompilationResult.
775 776 777 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 775 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_compilation_config ⇒ Google::Apis::DataformV1beta1::CodeCompilationConfig
Configures various aspects of Dataform code compilation.
Corresponds to the JSON property codeCompilationConfig
711 712 713 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 711 def code_compilation_config @code_compilation_config end |
#compilation_errors ⇒ Array<Google::Apis::DataformV1beta1::CompilationError>
Output only. Errors encountered during project compilation.
Corresponds to the JSON property compilationErrors
716 717 718 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 716 def compilation_errors @compilation_errors end |
#create_time ⇒ String
Output only. The timestamp of when the compilation result was created.
Corresponds to the JSON property createTime
721 722 723 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 721 def create_time @create_time end |
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
Corresponds to the JSON property dataEncryptionState
726 727 728 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 726 def data_encryption_state @data_encryption_state end |
#dataform_core_version ⇒ String
Output only. The version of @dataform/core that was used for compilation.
Corresponds to the JSON property dataformCoreVersion
731 732 733 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 731 def dataform_core_version @dataform_core_version end |
#git_commitish ⇒ String
Immutable. Git commit/tag/branch name at which the repository should be
compiled. Must exist in the remote repository. Examples: - a commit SHA:
12ade345 - a tag: tag1 - a branch name: branch1
Corresponds to the JSON property gitCommitish
738 739 740 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 738 def git_commitish @git_commitish end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
745 746 747 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 745 def @internal_metadata end |
#name ⇒ String
Output only. The compilation result's name.
Corresponds to the JSON property name
750 751 752 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 750 def name @name end |
#private_resource_metadata ⇒ Google::Apis::DataformV1beta1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
Corresponds to the JSON property privateResourceMetadata
755 756 757 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 755 def @private_resource_metadata end |
#release_config ⇒ String
Immutable. The name of the release config to compile. Must be in the format
projects/*/locations/*/repositories/*/releaseConfigs/*.
Corresponds to the JSON property releaseConfig
761 762 763 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 761 def release_config @release_config end |
#resolved_git_commit_sha ⇒ String
Output only. The fully resolved Git commit SHA of the code that was compiled.
Not set for compilation results whose source is a workspace.
Corresponds to the JSON property resolvedGitCommitSha
767 768 769 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 767 def resolved_git_commit_sha @resolved_git_commit_sha end |
#workspace ⇒ String
Immutable. The name of the workspace to compile. Must be in the format
projects/*/locations/*/repositories/*/workspaces/*.
Corresponds to the JSON property workspace
773 774 775 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 773 def workspace @workspace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
780 781 782 783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 780 def update!(**args) @code_compilation_config = args[:code_compilation_config] if args.key?(:code_compilation_config) @compilation_errors = args[:compilation_errors] if args.key?(:compilation_errors) @create_time = args[:create_time] if args.key?(:create_time) @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state) @dataform_core_version = args[:dataform_core_version] if args.key?(:dataform_core_version) @git_commitish = args[:git_commitish] if args.key?(:git_commitish) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @name = args[:name] if args.key?(:name) @private_resource_metadata = args[:private_resource_metadata] if args.key?(:private_resource_metadata) @release_config = args[:release_config] if args.key?(:release_config) @resolved_git_commit_sha = args[:resolved_git_commit_sha] if args.key?(:resolved_git_commit_sha) @workspace = args[:workspace] if args.key?(:workspace) end |