Class: Google::Apis::DataformV1beta1::CompilationResultAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a single Dataform action in a compilation result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompilationResultAction

Returns a new instance of CompilationResultAction.



868
869
870
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assertionGoogle::Apis::DataformV1beta1::Assertion

Represents an assertion upon a SQL query which is required return zero rows. Corresponds to the JSON property assertion



815
816
817
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 815

def assertion
  @assertion
end

#canonical_targetGoogle::Apis::DataformV1beta1::Target

Represents an action identifier. If the action writes output, the output will be written to the referenced database object. Corresponds to the JSON property canonicalTarget



821
822
823
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 821

def canonical_target
  @canonical_target
end

#data_preparationGoogle::Apis::DataformV1beta1::DataPreparation

Defines a compiled Data Preparation entity Corresponds to the JSON property dataPreparation



826
827
828
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 826

def data_preparation
  @data_preparation
end

#declarationGoogle::Apis::DataformV1beta1::Declaration

Represents a relation which is not managed by Dataform but which may be referenced by Dataform actions. Corresponds to the JSON property declaration



832
833
834
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 832

def declaration
  @declaration
end

#file_pathString

The full path including filename in which this action is located, relative to the workspace root. Corresponds to the JSON property filePath

Returns:

  • (String)


838
839
840
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 838

def file_path
  @file_path
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


845
846
847
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 845

def 
  @internal_metadata
end

#notebookGoogle::Apis::DataformV1beta1::Notebook

Represents a notebook. Corresponds to the JSON property notebook



850
851
852
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 850

def notebook
  @notebook
end

#operationsGoogle::Apis::DataformV1beta1::Operations

Represents a list of arbitrary database operations. Corresponds to the JSON property operations



855
856
857
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 855

def operations
  @operations
end

#relationGoogle::Apis::DataformV1beta1::Relation

Represents a database relation. Corresponds to the JSON property relation



860
861
862
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 860

def relation
  @relation
end

#targetGoogle::Apis::DataformV1beta1::Target

Represents an action identifier. If the action writes output, the output will be written to the referenced database object. Corresponds to the JSON property target



866
867
868
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 866

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



873
874
875
876
877
878
879
880
881
882
883
884
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 873

def update!(**args)
  @assertion = args[:assertion] if args.key?(:assertion)
  @canonical_target = args[:canonical_target] if args.key?(:canonical_target)
  @data_preparation = args[:data_preparation] if args.key?(:data_preparation)
  @declaration = args[:declaration] if args.key?(:declaration)
  @file_path = args[:file_path] if args.key?(:file_path)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @notebook = args[:notebook] if args.key?(:notebook)
  @operations = args[:operations] if args.key?(:operations)
  @relation = args[:relation] if args.key?(:relation)
  @target = args[:target] if args.key?(:target)
end