Class: Google::Apis::DataformV1beta1::DataPreparationAction
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::DataPreparationAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a workflow action that will run a Data Preparation.
Instance Attribute Summary collapse
-
#contents_sql ⇒ Google::Apis::DataformV1beta1::ActionSqlDefinition
Definition of a SQL Data Preparation Corresponds to the JSON property
contentsSql. -
#contents_yaml ⇒ String
Output only.
-
#generated_sql ⇒ String
Output only.
-
#job_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataPreparationAction
constructor
A new instance of DataPreparationAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataPreparationAction
Returns a new instance of DataPreparationAction.
1018 1019 1020 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents_sql ⇒ Google::Apis::DataformV1beta1::ActionSqlDefinition
Definition of a SQL Data Preparation
Corresponds to the JSON property contentsSql
998 999 1000 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 998 def contents_sql @contents_sql end |
#contents_yaml ⇒ String
Output only. YAML representing the contents of the data preparation. Can be
used to show the customer what the input was to their workflow.
Corresponds to the JSON property contentsYaml
1004 1005 1006 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1004 def contents_yaml @contents_yaml end |
#generated_sql ⇒ String
Output only. The generated BigQuery SQL script that will be executed. For
reference only.
Corresponds to the JSON property generatedSql
1010 1011 1012 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1010 def generated_sql @generated_sql end |
#job_id ⇒ String
Output only. The ID of the BigQuery job that executed the SQL in sql_script.
Only set once the job has started to run.
Corresponds to the JSON property jobId
1016 1017 1018 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1016 def job_id @job_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1023 1024 1025 1026 1027 1028 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1023 def update!(**args) @contents_sql = args[:contents_sql] if args.key?(:contents_sql) @contents_yaml = args[:contents_yaml] if args.key?(:contents_yaml) @generated_sql = args[:generated_sql] if args.key?(:generated_sql) @job_id = args[:job_id] if args.key?(:job_id) end |