Class: Google::Apis::DataformV1beta1::DeleteBranchRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::DeleteBranchRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
DeleteBranch request message.
Instance Attribute Summary collapse
-
#branch ⇒ String
Required.
-
#force ⇒ Boolean
(also: #force?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeleteBranchRequest
constructor
A new instance of DeleteBranchRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeleteBranchRequest
Returns a new instance of DeleteBranchRequest.
1142 1143 1144 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#branch ⇒ String
Required. The name of the branch in the Git repository to delete.
Corresponds to the JSON property branch
1133 1134 1135 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1133 def branch @branch end |
#force ⇒ Boolean Also known as: force?
Optional. If set to true, any non-pushed commits on the branch will be deleted.
Upstream branch name will be the same as the branch to delete.
Corresponds to the JSON property force
1139 1140 1141 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1139 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1147 1148 1149 1150 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1147 def update!(**args) @branch = args[:branch] if args.key?(:branch) @force = args[:force] if args.key?(:force) end |