Class: Google::Apis::DataformV1beta1::DeleteFolderTreeRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::DeleteFolderTreeRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
DeleteFolderTree request message.
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeleteFolderTreeRequest
constructor
A new instance of DeleteFolderTreeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeleteFolderTreeRequest
Returns a new instance of DeleteFolderTreeRequest.
1090 1091 1092 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1090 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Optional. If false (default): The operation will fail if any Repository
within the folder hierarchy has associated Release Configs or Workflow Configs.
If true: The operation will attempt to delete everything, including any
Release Configs and Workflow Configs linked to Repositories within the folder
hierarchy. This permanently removes schedules and resources.
Corresponds to the JSON property force
1087 1088 1089 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1087 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1095 1096 1097 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1095 def update!(**args) @force = args[:force] if args.key?(:force) end |