Class: Google::Apis::DataformV1beta1::DeleteRepositoryLongRunningRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::DeleteRepositoryLongRunningRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
DeleteRepositoryLongRunning request message.
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeleteRepositoryLongRunningRequest
constructor
A new instance of DeleteRepositoryLongRunningRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeleteRepositoryLongRunningRequest
Returns a new instance of DeleteRepositoryLongRunningRequest.
1115 1116 1117 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Optional. If set to true, child resources of this repository (compilation
results and workflow invocations) will also be deleted. Otherwise, the request
will only succeed if the repository has no child resources. Note: This
flag doesn't support deletion of workspaces, release configs or workflow
configs. If any of such resources exists in the repository, the request will
fail.
Corresponds to the JSON property force
1112 1113 1114 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1112 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1120 1121 1122 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1120 def update!(**args) @force = args[:force] if args.key?(:force) end |