Class: Google::Apis::DataformV1beta1::DeleteRepositoryLongRunningRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::DeleteRepositoryLongRunningRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
DeleteRepositoryLongRunning request message.
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeleteRepositoryLongRunningRequest
constructor
A new instance of DeleteRepositoryLongRunningRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeleteRepositoryLongRunningRequest
Returns a new instance of DeleteRepositoryLongRunningRequest.
1103 1104 1105 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1103 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Optional. If set to true, child resources of this repository (compilation
results and workflow invocations) will also be deleted. Otherwise, the request
will only succeed if the repository has no child resources. Note: This
flag doesn't support deletion of workspaces, release configs or workflow
configs. If any of such resources exists in the repository, the request will
fail.
Corresponds to the JSON property force
1100 1101 1102 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1100 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1108 1109 1110 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1108 def update!(**args) @force = args[:force] if args.key?(:force) end |