Class: Google::Apis::DataformV1beta1::DeleteTeamFolderTreeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

DeleteTeamFolderTree request message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteTeamFolderTreeRequest

Returns a new instance of DeleteTeamFolderTreeRequest.



1102
1103
1104
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

Optional. If false (default): The operation will fail if any Repository within the folder hierarchy has associated Release Configs or Workflow Configs. If true: The operation will attempt to delete everything, including any Release Configs and Workflow Configs linked to Repositories within the folder hierarchy. This permanently removes schedules and resources. Corresponds to the JSON property force

Returns:

  • (Boolean)


1099
1100
1101
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1099

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1107
1108
1109
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1107

def update!(**args)
  @force = args[:force] if args.key?(:force)
end