Class: Google::Apis::DataformV1beta1::FetchFileGitStatusesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::FetchFileGitStatusesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
FetchFileGitStatuses response message.
Instance Attribute Summary collapse
-
#uncommitted_file_changes ⇒ Array<Google::Apis::DataformV1beta1::UncommittedFileChange>
A list of all files which have uncommitted Git changes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchFileGitStatusesResponse
constructor
A new instance of FetchFileGitStatusesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchFileGitStatusesResponse
Returns a new instance of FetchFileGitStatusesResponse.
1287 1288 1289 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1287 def initialize(**args) update!(**args) end |
Instance Attribute Details
#uncommitted_file_changes ⇒ Array<Google::Apis::DataformV1beta1::UncommittedFileChange>
A list of all files which have uncommitted Git changes. There will only be a
single entry for any given file.
Corresponds to the JSON property uncommittedFileChanges
1285 1286 1287 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1285 def uncommitted_file_changes @uncommitted_file_changes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1292 1293 1294 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1292 def update!(**args) @uncommitted_file_changes = args[:uncommitted_file_changes] if args.key?(:uncommitted_file_changes) end |