Class: Google::Apis::DataformV1beta1::FilesystemEntryMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::FilesystemEntryMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents metadata for a single entry in a filesystem.
Instance Attribute Summary collapse
-
#size_bytes ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FilesystemEntryMetadata
constructor
A new instance of FilesystemEntryMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FilesystemEntryMetadata
Returns a new instance of FilesystemEntryMetadata.
1453 1454 1455 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1453 def initialize(**args) update!(**args) end |
Instance Attribute Details
#size_bytes ⇒ Fixnum
Output only. Provides the size of the entry in bytes. For directories, this
will be 0.
Corresponds to the JSON property sizeBytes
1446 1447 1448 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1446 def size_bytes @size_bytes end |
#update_time ⇒ String
Output only. Represents the time of the last modification of the entry.
Corresponds to the JSON property updateTime
1451 1452 1453 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1451 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1458 1459 1460 1461 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1458 def update!(**args) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @update_time = args[:update_time] if args.key?(:update_time) end |