Class: Google::Apis::DataformV1beta1::GitRemoteSettings
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::GitRemoteSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Controls Git remote configuration for a repository.
Instance Attribute Summary collapse
-
#authentication_token_secret_version ⇒ String
Optional.
-
#default_branch ⇒ String
Optional.
-
#effective_default_branch ⇒ String
Output only.
-
#git_repository_link ⇒ String
Optional.
-
#ssh_authentication_config ⇒ Google::Apis::DataformV1beta1::SshAuthenticationConfig
Configures fields for performing SSH authentication.
-
#token_status ⇒ String
Output only.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GitRemoteSettings
constructor
A new instance of GitRemoteSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GitRemoteSettings
Returns a new instance of GitRemoteSettings.
1820 1821 1822 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1820 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_token_secret_version ⇒ String
Optional. The name of the Secret Manager secret version to use as an
authentication token for Git operations. Must be in the format projects/*/
secrets/*/versions/*.
Corresponds to the JSON property authenticationTokenSecretVersion
1782 1783 1784 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1782 def authentication_token_secret_version @authentication_token_secret_version end |
#default_branch ⇒ String
Optional. The Git remote's default branch name. If not set, main will be
used.
Corresponds to the JSON property defaultBranch
1788 1789 1790 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1788 def default_branch @default_branch end |
#effective_default_branch ⇒ String
Output only. The Git remote's effective default branch name. This is the
default branch name of the Git remote if it is set, otherwise it is main.
Corresponds to the JSON property effectiveDefaultBranch
1794 1795 1796 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1794 def effective_default_branch @effective_default_branch end |
#git_repository_link ⇒ String
Optional. Resource name for the GitRepositoryLink used for machine
credentials. Must be in the format projects/*/locations/*/connections/*/
gitRepositoryLinks/*
Corresponds to the JSON property gitRepositoryLink
1801 1802 1803 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1801 def git_repository_link @git_repository_link end |
#ssh_authentication_config ⇒ Google::Apis::DataformV1beta1::SshAuthenticationConfig
Configures fields for performing SSH authentication.
Corresponds to the JSON property sshAuthenticationConfig
1806 1807 1808 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1806 def ssh_authentication_config @ssh_authentication_config end |
#token_status ⇒ String
Output only. Deprecated: The field does not contain any token status
information. Instead use https://cloud.google.com/dataform/reference/rest/
v1beta1/projects.locations.repositories/computeAccessTokenStatus
Corresponds to the JSON property tokenStatus
1813 1814 1815 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1813 def token_status @token_status end |
#url ⇒ String
Required. The Git remote's URL.
Corresponds to the JSON property url
1818 1819 1820 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1818 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1825 1826 1827 1828 1829 1830 1831 1832 1833 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1825 def update!(**args) @authentication_token_secret_version = args[:authentication_token_secret_version] if args.key?(:authentication_token_secret_version) @default_branch = args[:default_branch] if args.key?(:default_branch) @effective_default_branch = args[:effective_default_branch] if args.key?(:effective_default_branch) @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link) @ssh_authentication_config = args[:ssh_authentication_config] if args.key?(:ssh_authentication_config) @token_status = args[:token_status] if args.key?(:token_status) @url = args[:url] if args.key?(:url) end |