Class: Google::Apis::DataformV1beta1::GitRemoteSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Controls Git remote configuration for a repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitRemoteSettings

Returns a new instance of GitRemoteSettings.



1672
1673
1674
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_token_secret_versionString

Optional. The name of the Secret Manager secret version to use as an authentication token for Git operations. Must be in the format projects/*/ secrets/*/versions/*. Corresponds to the JSON property authenticationTokenSecretVersion

Returns:

  • (String)


1634
1635
1636
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1634

def authentication_token_secret_version
  @authentication_token_secret_version
end

#default_branchString

Optional. The Git remote's default branch name. If not set, main will be used. Corresponds to the JSON property defaultBranch

Returns:

  • (String)


1640
1641
1642
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1640

def default_branch
  @default_branch
end

#effective_default_branchString

Output only. The Git remote's effective default branch name. This is the default branch name of the Git remote if it is set, otherwise it is main. Corresponds to the JSON property effectiveDefaultBranch

Returns:

  • (String)


1646
1647
1648
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1646

def effective_default_branch
  @effective_default_branch
end

Optional. Resource name for the GitRepositoryLink used for machine credentials. Must be in the format projects/*/locations/*/connections/*/ gitRepositoryLinks/* Corresponds to the JSON property gitRepositoryLink

Returns:

  • (String)


1653
1654
1655
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1653

def git_repository_link
  @git_repository_link
end

#ssh_authentication_configGoogle::Apis::DataformV1beta1::SshAuthenticationConfig

Configures fields for performing SSH authentication. Corresponds to the JSON property sshAuthenticationConfig



1658
1659
1660
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1658

def ssh_authentication_config
  @ssh_authentication_config
end

#token_statusString

Output only. Deprecated: The field does not contain any token status information. Instead use https://cloud.google.com/dataform/reference/rest/ v1beta1/projects.locations.repositories/computeAccessTokenStatus Corresponds to the JSON property tokenStatus

Returns:

  • (String)


1665
1666
1667
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1665

def token_status
  @token_status
end

#urlString

Required. The Git remote's URL. Corresponds to the JSON property url

Returns:

  • (String)


1670
1671
1672
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1670

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1677
1678
1679
1680
1681
1682
1683
1684
1685
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1677

def update!(**args)
  @authentication_token_secret_version = args[:authentication_token_secret_version] if args.key?(:authentication_token_secret_version)
  @default_branch = args[:default_branch] if args.key?(:default_branch)
  @effective_default_branch = args[:effective_default_branch] if args.key?(:effective_default_branch)
  @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link)
  @ssh_authentication_config = args[:ssh_authentication_config] if args.key?(:ssh_authentication_config)
  @token_status = args[:token_status] if args.key?(:token_status)
  @url = args[:url] if args.key?(:url)
end