Class: Google::Apis::DataformV1beta1::GitRemoteSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Controls Git remote configuration for a repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitRemoteSettings

Returns a new instance of GitRemoteSettings.



1599
1600
1601
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_token_secret_versionString

Optional. The name of the Secret Manager secret version to use as an authentication token for Git operations. Must be in the format projects/*/ secrets/*/versions/*. Corresponds to the JSON property authenticationTokenSecretVersion

Returns:

  • (String)


1569
1570
1571
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1569

def authentication_token_secret_version
  @authentication_token_secret_version
end

#default_branchString

Optional. The Git remote's default branch name. If not set main will be used. Corresponds to the JSON property defaultBranch

Returns:

  • (String)


1574
1575
1576
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1574

def default_branch
  @default_branch
end

#effective_default_branchString

Output only. The Git remote's effective default branch name. This is the default branch name of the Git remote if it is set, otherwise it is main. Corresponds to the JSON property effectiveDefaultBranch

Returns:

  • (String)


1580
1581
1582
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1580

def effective_default_branch
  @effective_default_branch
end

#ssh_authentication_configGoogle::Apis::DataformV1beta1::SshAuthenticationConfig

Configures fields for performing SSH authentication. Corresponds to the JSON property sshAuthenticationConfig



1585
1586
1587
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1585

def ssh_authentication_config
  @ssh_authentication_config
end

#token_statusString

Output only. Deprecated: The field does not contain any token status information. Instead use https://cloud.google.com/dataform/reference/rest/ v1beta1/projects.locations.repositories/computeAccessTokenStatus Corresponds to the JSON property tokenStatus

Returns:

  • (String)


1592
1593
1594
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1592

def token_status
  @token_status
end

#urlString

Required. The Git remote's URL. Corresponds to the JSON property url

Returns:

  • (String)


1597
1598
1599
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1597

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1604
1605
1606
1607
1608
1609
1610
1611
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1604

def update!(**args)
  @authentication_token_secret_version = args[:authentication_token_secret_version] if args.key?(:authentication_token_secret_version)
  @default_branch = args[:default_branch] if args.key?(:default_branch)
  @effective_default_branch = args[:effective_default_branch] if args.key?(:effective_default_branch)
  @ssh_authentication_config = args[:ssh_authentication_config] if args.key?(:ssh_authentication_config)
  @token_status = args[:token_status] if args.key?(:token_status)
  @url = args[:url] if args.key?(:url)
end