Class: Google::Apis::DataformV1beta1::GitRemoteSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Controls Git remote configuration for a repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitRemoteSettings

Returns a new instance of GitRemoteSettings.



1567
1568
1569
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_token_secret_versionString

Optional. The name of the Secret Manager secret version to use as an authentication token for Git operations. Must be in the format projects/*/ secrets/*/versions/*. Corresponds to the JSON property authenticationTokenSecretVersion

Returns:

  • (String)


1542
1543
1544
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1542

def authentication_token_secret_version
  @authentication_token_secret_version
end

#default_branchString

Required. The Git remote's default branch name. If not set, main will be used and stored for the repository. Corresponds to the JSON property defaultBranch

Returns:

  • (String)


1548
1549
1550
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1548

def default_branch
  @default_branch
end

#ssh_authentication_configGoogle::Apis::DataformV1beta1::SshAuthenticationConfig

Configures fields for performing SSH authentication. Corresponds to the JSON property sshAuthenticationConfig



1553
1554
1555
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1553

def ssh_authentication_config
  @ssh_authentication_config
end

#token_statusString

Output only. Deprecated: The field does not contain any token status information. Instead use https://cloud.google.com/dataform/reference/rest/ v1beta1/projects.locations.repositories/computeAccessTokenStatus Corresponds to the JSON property tokenStatus

Returns:

  • (String)


1560
1561
1562
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1560

def token_status
  @token_status
end

#urlString

Required. The Git remote's URL. Corresponds to the JSON property url

Returns:

  • (String)


1565
1566
1567
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1565

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1572
1573
1574
1575
1576
1577
1578
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1572

def update!(**args)
  @authentication_token_secret_version = args[:authentication_token_secret_version] if args.key?(:authentication_token_secret_version)
  @default_branch = args[:default_branch] if args.key?(:default_branch)
  @ssh_authentication_config = args[:ssh_authentication_config] if args.key?(:ssh_authentication_config)
  @token_status = args[:token_status] if args.key?(:token_status)
  @url = args[:url] if args.key?(:url)
end