Class: Google::Apis::DataformV1beta1::IamPolicyOverrideView
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::IamPolicyOverrideView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Contains metadata about the IAM policy override for a given Dataform resource. If is_active is true, this the policy encoded in iam_policy_name is the source of truth for this resource. Will be provided in internal ESV2 views for: Workspaces, Repositories, Folders, TeamFolders.
Instance Attribute Summary collapse
-
#iam_policy_name ⇒ Google::Apis::DataformV1beta1::PolicyName
An internal name for an IAM policy, based on the resource to which the policy applies.
-
#is_active ⇒ Boolean
(also: #is_active?)
Whether the IAM policy encoded in this view is active.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IamPolicyOverrideView
constructor
A new instance of IamPolicyOverrideView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IamPolicyOverrideView
Returns a new instance of IamPolicyOverrideView.
1634 1635 1636 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1634 def initialize(**args) update!(**args) end |
Instance Attribute Details
#iam_policy_name ⇒ Google::Apis::DataformV1beta1::PolicyName
An internal name for an IAM policy, based on the resource to which the policy
applies. Not to be confused with a resource's external full resource name. For
more information on this distinction, see go/iam-full-resource-names.
Corresponds to the JSON property iamPolicyName
1626 1627 1628 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1626 def iam_policy_name @iam_policy_name end |
#is_active ⇒ Boolean Also known as: is_active?
Whether the IAM policy encoded in this view is active.
Corresponds to the JSON property isActive
1631 1632 1633 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1631 def is_active @is_active end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1639 1640 1641 1642 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1639 def update!(**args) @iam_policy_name = args[:iam_policy_name] if args.key?(:iam_policy_name) @is_active = args[:is_active] if args.key?(:is_active) end |