Class: Google::Apis::DataformV1beta1::IamPolicyOverrideView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Contains metadata about the IAM policy override for a given Dataform resource. If is_active is true, this the policy encoded in iam_policy_name is the source of truth for this resource. Will be provided in internal ESV2 views for: Workspaces, Repositories, Folders, TeamFolders.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IamPolicyOverrideView

Returns a new instance of IamPolicyOverrideView.



1601
1602
1603
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1601

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#iam_policy_nameGoogle::Apis::DataformV1beta1::PolicyName

An internal name for an IAM policy, based on the resource to which the policy applies. Not to be confused with a resource's external full resource name. For more information on this distinction, see go/iam-full-resource-names. Corresponds to the JSON property iamPolicyName



1593
1594
1595
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1593

def iam_policy_name
  @iam_policy_name
end

#is_activeBoolean Also known as: is_active?

Whether the IAM policy encoded in this view is active. Corresponds to the JSON property isActive

Returns:

  • (Boolean)


1598
1599
1600
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1598

def is_active
  @is_active
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1606
1607
1608
1609
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1606

def update!(**args)
  @iam_policy_name = args[:iam_policy_name] if args.key?(:iam_policy_name)
  @is_active = args[:is_active] if args.key?(:is_active)
end