Class: Google::Apis::DataformV1beta1::InvocationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::InvocationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Includes various configuration options for a workflow invocation. If both
included_targets and included_tags are unset, all actions will be included.
Instance Attribute Summary collapse
-
#fully_refresh_incremental_tables_enabled ⇒ Boolean
(also: #fully_refresh_incremental_tables_enabled?)
Optional.
-
#included_tags ⇒ Array<String>
Optional.
-
#included_targets ⇒ Array<Google::Apis::DataformV1beta1::Target>
Optional.
-
#query_priority ⇒ String
Optional.
-
#service_account ⇒ String
Optional.
-
#transitive_dependencies_included ⇒ Boolean
(also: #transitive_dependencies_included?)
Optional.
-
#transitive_dependents_included ⇒ Boolean
(also: #transitive_dependents_included?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InvocationConfig
constructor
A new instance of InvocationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InvocationConfig
Returns a new instance of InvocationConfig.
1830 1831 1832 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fully_refresh_incremental_tables_enabled ⇒ Boolean Also known as: fully_refresh_incremental_tables_enabled?
Optional. When set to true, any incremental tables will be fully refreshed.
Corresponds to the JSON property fullyRefreshIncrementalTablesEnabled
1791 1792 1793 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1791 def fully_refresh_incremental_tables_enabled @fully_refresh_incremental_tables_enabled end |
#included_tags ⇒ Array<String>
Optional. The set of tags to include.
Corresponds to the JSON property includedTags
1797 1798 1799 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1797 def @included_tags end |
#included_targets ⇒ Array<Google::Apis::DataformV1beta1::Target>
Optional. The set of action identifiers to include.
Corresponds to the JSON property includedTargets
1802 1803 1804 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1802 def included_targets @included_targets end |
#query_priority ⇒ String
Optional. Specifies the priority for query execution in BigQuery. More
information can be found at https://cloud.google.com/bigquery/docs/running-
queries#queries.
Corresponds to the JSON property queryPriority
1809 1810 1811 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1809 def query_priority @query_priority end |
#service_account ⇒ String
Optional. The service account to run workflow invocations under.
Corresponds to the JSON property serviceAccount
1814 1815 1816 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1814 def service_account @service_account end |
#transitive_dependencies_included ⇒ Boolean Also known as: transitive_dependencies_included?
Optional. When set to true, transitive dependencies of included actions will
be executed.
Corresponds to the JSON property transitiveDependenciesIncluded
1820 1821 1822 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1820 def transitive_dependencies_included @transitive_dependencies_included end |
#transitive_dependents_included ⇒ Boolean Also known as: transitive_dependents_included?
Optional. When set to true, transitive dependents of included actions will be
executed.
Corresponds to the JSON property transitiveDependentsIncluded
1827 1828 1829 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1827 def transitive_dependents_included @transitive_dependents_included end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1835 1836 1837 1838 1839 1840 1841 1842 1843 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1835 def update!(**args) @fully_refresh_incremental_tables_enabled = args[:fully_refresh_incremental_tables_enabled] if args.key?(:fully_refresh_incremental_tables_enabled) @included_tags = args[:included_tags] if args.key?(:included_tags) @included_targets = args[:included_targets] if args.key?(:included_targets) @query_priority = args[:query_priority] if args.key?(:query_priority) @service_account = args[:service_account] if args.key?(:service_account) @transitive_dependencies_included = args[:transitive_dependencies_included] if args.key?(:transitive_dependencies_included) @transitive_dependents_included = args[:transitive_dependents_included] if args.key?(:transitive_dependents_included) end |