Class: Google::Apis::DataformV1beta1::InvocationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Includes various configuration options for a workflow invocation. If both included_targets and included_tags are unset, all actions will be included.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InvocationConfig

Returns a new instance of InvocationConfig.



1789
1790
1791
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1789

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fully_refresh_incremental_tables_enabledBoolean Also known as: fully_refresh_incremental_tables_enabled?

Optional. When set to true, any incremental tables will be fully refreshed. Corresponds to the JSON property fullyRefreshIncrementalTablesEnabled

Returns:

  • (Boolean)


1750
1751
1752
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1750

def fully_refresh_incremental_tables_enabled
  @fully_refresh_incremental_tables_enabled
end

#included_tagsArray<String>

Optional. The set of tags to include. Corresponds to the JSON property includedTags

Returns:

  • (Array<String>)


1756
1757
1758
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1756

def included_tags
  @included_tags
end

#included_targetsArray<Google::Apis::DataformV1beta1::Target>

Optional. The set of action identifiers to include. Corresponds to the JSON property includedTargets



1761
1762
1763
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1761

def included_targets
  @included_targets
end

#query_priorityString

Optional. Specifies the priority for query execution in BigQuery. More information can be found at https://cloud.google.com/bigquery/docs/running- queries#queries. Corresponds to the JSON property queryPriority

Returns:

  • (String)


1768
1769
1770
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1768

def query_priority
  @query_priority
end

#service_accountString

Optional. The service account to run workflow invocations under. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1773
1774
1775
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1773

def 
  @service_account
end

#transitive_dependencies_includedBoolean Also known as: transitive_dependencies_included?

Optional. When set to true, transitive dependencies of included actions will be executed. Corresponds to the JSON property transitiveDependenciesIncluded

Returns:

  • (Boolean)


1779
1780
1781
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1779

def transitive_dependencies_included
  @transitive_dependencies_included
end

#transitive_dependents_includedBoolean Also known as: transitive_dependents_included?

Optional. When set to true, transitive dependents of included actions will be executed. Corresponds to the JSON property transitiveDependentsIncluded

Returns:

  • (Boolean)


1786
1787
1788
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1786

def transitive_dependents_included
  @transitive_dependents_included
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1794
1795
1796
1797
1798
1799
1800
1801
1802
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 1794

def update!(**args)
  @fully_refresh_incremental_tables_enabled = args[:fully_refresh_incremental_tables_enabled] if args.key?(:fully_refresh_incremental_tables_enabled)
  @included_tags = args[:included_tags] if args.key?(:included_tags)
  @included_targets = args[:included_targets] if args.key?(:included_targets)
  @query_priority = args[:query_priority] if args.key?(:query_priority)
  @service_account = args[:service_account] if args.key?(:service_account)
  @transitive_dependencies_included = args[:transitive_dependencies_included] if args.key?(:transitive_dependencies_included)
  @transitive_dependents_included = args[:transitive_dependents_included] if args.key?(:transitive_dependents_included)
end