Class: Google::Apis::DataformV1beta1::LoadConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::LoadConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Simplified load configuration for actions
Instance Attribute Summary collapse
-
#append ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition Corresponds to the JSON property
append. -
#maximum ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes Corresponds to the JSON property
maximum. -
#replace ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition Corresponds to the JSON property
replace. -
#unique ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes Corresponds to the JSON property
unique.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadConfig
constructor
A new instance of LoadConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadConfig
Returns a new instance of LoadConfig.
2115 2116 2117 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#append ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition
Corresponds to the JSON property append
2098 2099 2100 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2098 def append @append end |
#maximum ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes
Corresponds to the JSON property maximum
2103 2104 2105 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2103 def maximum @maximum end |
#replace ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition
Corresponds to the JSON property replace
2108 2109 2110 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2108 def replace @replace end |
#unique ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes
Corresponds to the JSON property unique
2113 2114 2115 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2113 def unique @unique end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2120 2121 2122 2123 2124 2125 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2120 def update!(**args) @append = args[:append] if args.key?(:append) @maximum = args[:maximum] if args.key?(:maximum) @replace = args[:replace] if args.key?(:replace) @unique = args[:unique] if args.key?(:unique) end |