Class: Google::Apis::DataformV1beta1::LoadConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::LoadConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Simplified load configuration for actions
Instance Attribute Summary collapse
-
#append ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition Corresponds to the JSON property
append. -
#maximum ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes Corresponds to the JSON property
maximum. -
#replace ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition Corresponds to the JSON property
replace. -
#unique ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes Corresponds to the JSON property
unique.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadConfig
constructor
A new instance of LoadConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadConfig
Returns a new instance of LoadConfig.
2080 2081 2082 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#append ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition
Corresponds to the JSON property append
2063 2064 2065 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2063 def append @append end |
#maximum ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes
Corresponds to the JSON property maximum
2068 2069 2070 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2068 def maximum @maximum end |
#replace ⇒ Google::Apis::DataformV1beta1::SimpleLoadMode
Simple load definition
Corresponds to the JSON property replace
2073 2074 2075 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2073 def replace @replace end |
#unique ⇒ Google::Apis::DataformV1beta1::IncrementalLoadMode
Load definition for incremental load modes
Corresponds to the JSON property unique
2078 2079 2080 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2078 def unique @unique end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2085 2086 2087 2088 2089 2090 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2085 def update!(**args) @append = args[:append] if args.key?(:append) @maximum = args[:maximum] if args.key?(:maximum) @replace = args[:replace] if args.key?(:replace) @unique = args[:unique] if args.key?(:unique) end |