Class: Google::Apis::DataformV1beta1::Notebook
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::Notebook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a notebook.
Instance Attribute Summary collapse
-
#contents ⇒ String
The contents of the notebook.
-
#dependency_targets ⇒ Array<Google::Apis::DataformV1beta1::Target>
A list of actions that this action depends on.
-
#disabled ⇒ Boolean
(also: #disabled?)
Whether this action is disabled (i.e. should not be run).
-
#tags ⇒ Array<String>
Arbitrary, user-defined tags on this action.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Notebook
constructor
A new instance of Notebook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Notebook
Returns a new instance of Notebook.
2355 2356 2357 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2355 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
The contents of the notebook.
Corresponds to the JSON property contents
2337 2338 2339 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2337 def contents @contents end |
#dependency_targets ⇒ Array<Google::Apis::DataformV1beta1::Target>
A list of actions that this action depends on.
Corresponds to the JSON property dependencyTargets
2342 2343 2344 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2342 def dependency_targets @dependency_targets end |
#disabled ⇒ Boolean Also known as: disabled?
Whether this action is disabled (i.e. should not be run).
Corresponds to the JSON property disabled
2347 2348 2349 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2347 def disabled @disabled end |
#tags ⇒ Array<String>
Arbitrary, user-defined tags on this action.
Corresponds to the JSON property tags
2353 2354 2355 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2353 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2360 2361 2362 2363 2364 2365 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2360 def update!(**args) @contents = args[:contents] if args.key?(:contents) @dependency_targets = args[:dependency_targets] if args.key?(:dependency_targets) @disabled = args[:disabled] if args.key?(:disabled) @tags = args[:tags] if args.key?(:tags) end |