Class: Google::Apis::DataformV1beta1::NotebookAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a workflow action that will run against a Notebook runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotebookAction

Returns a new instance of NotebookAction.



2467
2468
2469
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

Output only. The code contents of a Notebook to be run. Corresponds to the JSON property contents

Returns:

  • (String)


2453
2454
2455
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2453

def contents
  @contents
end

#file_pathString

Output only. The path to the notebook file in the repository. Corresponds to the JSON property filePath

Returns:

  • (String)


2458
2459
2460
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2458

def file_path
  @file_path
end

#job_idString

Output only. The ID of the Gemini Enterprise Agent Platform job that executed the notebook in contents and also the ID used for the outputs created in Google Cloud Storage buckets. Only set once the job has started to run. Corresponds to the JSON property jobId

Returns:

  • (String)


2465
2466
2467
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2465

def job_id
  @job_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2472
2473
2474
2475
2476
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2472

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @file_path = args[:file_path] if args.key?(:file_path)
  @job_id = args[:job_id] if args.key?(:job_id)
end