Class: Google::Apis::DataformV1beta1::NotebookAction
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::NotebookAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a workflow action that will run against a Notebook runtime.
Instance Attribute Summary collapse
-
#contents ⇒ String
Output only.
-
#job_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotebookAction
constructor
A new instance of NotebookAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotebookAction
Returns a new instance of NotebookAction.
2384 2385 2386 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2384 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
Output only. The code contents of a Notebook to be run.
Corresponds to the JSON property contents
2375 2376 2377 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2375 def contents @contents end |
#job_id ⇒ String
Output only. The ID of the Gemini Enterprise Agent Platform job that executed
the notebook in contents and also the ID used for the outputs created in
Google Cloud Storage buckets. Only set once the job has started to run.
Corresponds to the JSON property jobId
2382 2383 2384 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2382 def job_id @job_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2389 2390 2391 2392 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2389 def update!(**args) @contents = args[:contents] if args.key?(:contents) @job_id = args[:job_id] if args.key?(:job_id) end |