Class: Google::Apis::DataformV1beta1::NotebookRuntimeOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Configures various aspects of Dataform notebook runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotebookRuntimeOptions

Returns a new instance of NotebookRuntimeOptions.



2502
2503
2504
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_platform_notebook_runtime_templateString

Optional. The resource name of the Colab runtime template, from which a runtime is created for notebook executions. If not specified, a runtime is created with Colab's default specifications. Corresponds to the JSON property aiPlatformNotebookRuntimeTemplate

Returns:

  • (String)


2489
2490
2491
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2489

def ai_platform_notebook_runtime_template
  @ai_platform_notebook_runtime_template
end

#gcs_output_bucketString

Optional. The Google Cloud Storage location to upload the result to. Format: gs://bucket-name. Corresponds to the JSON property gcsOutputBucket

Returns:

  • (String)


2495
2496
2497
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2495

def gcs_output_bucket
  @gcs_output_bucket
end

#gcs_repository_snapshot_destinationGoogle::Apis::DataformV1beta1::GcsRepositorySnapshotDestination

Configures the destination for a repository snapshot. Corresponds to the JSON property gcsRepositorySnapshotDestination



2500
2501
2502
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2500

def gcs_repository_snapshot_destination
  @gcs_repository_snapshot_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2507
2508
2509
2510
2511
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2507

def update!(**args)
  @ai_platform_notebook_runtime_template = args[:ai_platform_notebook_runtime_template] if args.key?(:ai_platform_notebook_runtime_template)
  @gcs_output_bucket = args[:gcs_output_bucket] if args.key?(:gcs_output_bucket)
  @gcs_repository_snapshot_destination = args[:gcs_repository_snapshot_destination] if args.key?(:gcs_repository_snapshot_destination)
end