Class: Google::Apis::DataformV1beta1::NotebookRuntimeOptions
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::NotebookRuntimeOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Configures various aspects of Dataform notebook runtime.
Instance Attribute Summary collapse
-
#ai_platform_notebook_runtime_template ⇒ String
Optional.
-
#gcs_output_bucket ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotebookRuntimeOptions
constructor
A new instance of NotebookRuntimeOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotebookRuntimeOptions
Returns a new instance of NotebookRuntimeOptions.
2378 2379 2380 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_platform_notebook_runtime_template ⇒ String
Optional. The resource name of the Colab runtime template, from which a runtime is created for notebook
executions. If not specified, a runtime is created with Colab's default
specifications.
Corresponds to the JSON property aiPlatformNotebookRuntimeTemplate
2370 2371 2372 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2370 def ai_platform_notebook_runtime_template @ai_platform_notebook_runtime_template end |
#gcs_output_bucket ⇒ String
Optional. The Google Cloud Storage location to upload the result to. Format:
gs://bucket-name.
Corresponds to the JSON property gcsOutputBucket
2376 2377 2378 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2376 def gcs_output_bucket @gcs_output_bucket end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2383 2384 2385 2386 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2383 def update!(**args) @ai_platform_notebook_runtime_template = args[:ai_platform_notebook_runtime_template] if args.key?(:ai_platform_notebook_runtime_template) @gcs_output_bucket = args[:gcs_output_bucket] if args.key?(:gcs_output_bucket) end |