Class: Google::Apis::DataformV1beta1::PipelineConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Defines the pipeline type and path within the Git repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PipelineConfig

Returns a new instance of PipelineConfig.



2702
2703
2704
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pathString

Required. The relative path within the Git repository where the pipeline is defined. For example, for a Dataform pipeline, it is a path to the folder where workflow_settings.yaml or dataform.json is located. Corresponds to the JSON property path

Returns:

  • (String)


2695
2696
2697
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2695

def path
  @path
end

#pipeline_typeString

Required. The type of the pipeline. Corresponds to the JSON property pipelineType

Returns:

  • (String)


2700
2701
2702
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2700

def pipeline_type
  @pipeline_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2707
2708
2709
2710
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 2707

def update!(**args)
  @path = args[:path] if args.key?(:path)
  @pipeline_type = args[:pipeline_type] if args.key?(:pipeline_type)
end