Class: Google::Apis::DataformV1beta1::RelationDescriptor
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::RelationDescriptor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Describes a relation and its columns.
Instance Attribute Summary collapse
-
#bigquery_labels ⇒ Hash<String,String>
A set of BigQuery labels that should be applied to the relation.
-
#columns ⇒ Array<Google::Apis::DataformV1beta1::ColumnDescriptor>
A list of descriptions of columns within the relation.
-
#description ⇒ String
A text description of the relation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RelationDescriptor
constructor
A new instance of RelationDescriptor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RelationDescriptor
Returns a new instance of RelationDescriptor.
3156 3157 3158 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3156 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_labels ⇒ Hash<String,String>
A set of BigQuery labels that should be applied to the relation.
Corresponds to the JSON property bigqueryLabels
3144 3145 3146 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3144 def bigquery_labels @bigquery_labels end |
#columns ⇒ Array<Google::Apis::DataformV1beta1::ColumnDescriptor>
A list of descriptions of columns within the relation.
Corresponds to the JSON property columns
3149 3150 3151 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3149 def columns @columns end |
#description ⇒ String
A text description of the relation.
Corresponds to the JSON property description
3154 3155 3156 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3154 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3161 3162 3163 3164 3165 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3161 def update!(**args) @bigquery_labels = args[:bigquery_labels] if args.key?(:bigquery_labels) @columns = args[:columns] if args.key?(:columns) @description = args[:description] if args.key?(:description) end |