Class: Google::Apis::DataformV1beta1::Repository

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a Dataform Git repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Repository

Returns a new instance of Repository.



3569
3570
3571
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3569

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containing_folderString

Optional. The name of the containing folder of the repository. The field is immutable and it can be modified via a MoveRepository operation. Format: projects/*/locations/*/folders/*. or projects/*/locations/*/teamFolders/*. Corresponds to the JSON property containingFolder

Returns:

  • (String)


3479
3480
3481
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3479

def containing_folder
  @containing_folder
end

#create_timeString

Output only. The timestamp of when the repository was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3484
3485
3486
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3484

def create_time
  @create_time
end

#data_encryption_stateGoogle::Apis::DataformV1beta1::DataEncryptionState

Describes encryption state of a resource. Corresponds to the JSON property dataEncryptionState



3489
3490
3491
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3489

def data_encryption_state
  @data_encryption_state
end

#display_nameString

Optional. The repository's user-friendly name. Corresponds to the JSON property displayName

Returns:

  • (String)


3494
3495
3496
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3494

def display_name
  @display_name
end

#git_remote_settingsGoogle::Apis::DataformV1beta1::GitRemoteSettings

Controls Git remote configuration for a repository. Corresponds to the JSON property gitRemoteSettings



3499
3500
3501
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3499

def git_remote_settings
  @git_remote_settings
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


3506
3507
3508
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3506

def 
  @internal_metadata
end

#kms_key_nameString

Optional. The reference to a KMS encryption key. If provided, it will be used to encrypt user data in the repository and all child resources. It is not possible to add or update the encryption key after the repository is created. Example: projects/kms_project/locations/location/keyRings/key_location/ cryptoKeys/key` Corresponds to the JSON propertykmsKeyName`

Returns:

  • (String)


3515
3516
3517
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3515

def kms_key_name
  @kms_key_name
end

#labelsHash<String,String>

Optional. Repository user labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3520
3521
3522
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3520

def labels
  @labels
end

#nameString

Identifier. The repository's name. Corresponds to the JSON property name

Returns:

  • (String)


3525
3526
3527
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3525

def name
  @name
end

#npmrc_environment_variables_secret_versionString

Optional. The name of the Secret Manager secret version to be used to interpolate variables into the .npmrc file for package installation operations. Must be in the format projects/*/secrets/*/versions/*. The file itself must be in a JSON format. Corresponds to the JSON property npmrcEnvironmentVariablesSecretVersion

Returns:

  • (String)


3533
3534
3535
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3533

def npmrc_environment_variables_secret_version
  @npmrc_environment_variables_secret_version
end

#service_accountString

Optional. The service account to run workflow invocations under. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


3538
3539
3540
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3538

def 
  @service_account
end

#set_authenticated_user_adminBoolean Also known as: set_authenticated_user_admin?

Optional. Input only. If set to true, the authenticated user will be granted the roles/dataform.admin role on the created repository. To modify access to the created repository later apply setIamPolicy from https://cloud.google.com/ dataform/reference/rest#rest-resource:-v1beta1.projects.locations.repositories Corresponds to the JSON property setAuthenticatedUserAdmin

Returns:

  • (Boolean)


3546
3547
3548
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3546

def set_authenticated_user_admin
  @set_authenticated_user_admin
end

#team_folder_nameString

Output only. The resource name of the TeamFolder that this Repository is associated with. This should take the format: projects/project/locations/ location/teamFolders/teamFolder. If this is not set, the Repository is not associated with a TeamFolder. Corresponds to the JSON property teamFolderName

Returns:

  • (String)


3555
3556
3557
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3555

def team_folder_name
  @team_folder_name
end

#workspace_compilation_overridesGoogle::Apis::DataformV1beta1::WorkspaceCompilationOverrides

Configures workspace compilation overrides for a repository. Primarily used by the UI (console.cloud.google.com). schema_suffix and table_prefix can have a special expression - $workspaceName`, which refers to the workspace name from which the compilation results will be created. API callers are expected to resolve the expression in these overrides and provide them explicitly incode_compilation_config(https://cloud.google.com/dataform/ reference/rest/v1beta1/projects.locations.repositories.compilationResults# codecompilationconfig) when creating workspace-scoped compilation results. Corresponds to the JSON propertyworkspaceCompilationOverrides`



3567
3568
3569
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3567

def workspace_compilation_overrides
  @workspace_compilation_overrides
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3574
3575
3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3574

def update!(**args)
  @containing_folder = args[:containing_folder] if args.key?(:containing_folder)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state)
  @display_name = args[:display_name] if args.key?(:display_name)
  @git_remote_settings = args[:git_remote_settings] if args.key?(:git_remote_settings)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @npmrc_environment_variables_secret_version = args[:npmrc_environment_variables_secret_version] if args.key?(:npmrc_environment_variables_secret_version)
  @service_account = args[:service_account] if args.key?(:service_account)
  @set_authenticated_user_admin = args[:set_authenticated_user_admin] if args.key?(:set_authenticated_user_admin)
  @team_folder_name = args[:team_folder_name] if args.key?(:team_folder_name)
  @workspace_compilation_overrides = args[:workspace_compilation_overrides] if args.key?(:workspace_compilation_overrides)
end