Class: Google::Apis::DataformV1beta1::Repository
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::Repository
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a Dataform Git repository.
Instance Attribute Summary collapse
-
#containing_folder ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
-
#display_name ⇒ String
Optional.
-
#git_remote_settings ⇒ Google::Apis::DataformV1beta1::GitRemoteSettings
Controls Git remote configuration for a repository.
-
#internal_metadata ⇒ String
Output only.
-
#kms_key_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#npmrc_environment_variables_secret_version ⇒ String
Optional.
-
#service_account ⇒ String
Optional.
-
#set_authenticated_user_admin ⇒ Boolean
(also: #set_authenticated_user_admin?)
Optional.
-
#team_folder_name ⇒ String
Output only.
-
#workspace_compilation_overrides ⇒ Google::Apis::DataformV1beta1::WorkspaceCompilationOverrides
Configures workspace compilation overrides for a repository.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Repository
constructor
A new instance of Repository.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Repository
Returns a new instance of Repository.
3416 3417 3418 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#containing_folder ⇒ String
Optional. The name of the containing folder of the repository. The field is
immutable and it can be modified via a MoveRepository operation. Format:
projects/*/locations/*/folders/*. or projects/*/locations/*/teamFolders/*.
Corresponds to the JSON property containingFolder
3326 3327 3328 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3326 def containing_folder @containing_folder end |
#create_time ⇒ String
Output only. The timestamp of when the repository was created.
Corresponds to the JSON property createTime
3331 3332 3333 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3331 def create_time @create_time end |
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
Corresponds to the JSON property dataEncryptionState
3336 3337 3338 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3336 def data_encryption_state @data_encryption_state end |
#display_name ⇒ String
Optional. The repository's user-friendly name.
Corresponds to the JSON property displayName
3341 3342 3343 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3341 def display_name @display_name end |
#git_remote_settings ⇒ Google::Apis::DataformV1beta1::GitRemoteSettings
Controls Git remote configuration for a repository.
Corresponds to the JSON property gitRemoteSettings
3346 3347 3348 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3346 def git_remote_settings @git_remote_settings end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
3353 3354 3355 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3353 def @internal_metadata end |
#kms_key_name ⇒ String
Optional. The reference to a KMS encryption key. If provided, it will be used
to encrypt user data in the repository and all child resources. It is not
possible to add or update the encryption key after the repository is created.
Example: projects/kms_project/locations/location/keyRings/key_location/
cryptoKeys/key`
Corresponds to the JSON propertykmsKeyName`
3362 3363 3364 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3362 def kms_key_name @kms_key_name end |
#labels ⇒ Hash<String,String>
Optional. Repository user labels.
Corresponds to the JSON property labels
3367 3368 3369 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3367 def labels @labels end |
#name ⇒ String
Identifier. The repository's name.
Corresponds to the JSON property name
3372 3373 3374 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3372 def name @name end |
#npmrc_environment_variables_secret_version ⇒ String
Optional. The name of the Secret Manager secret version to be used to
interpolate variables into the .npmrc file for package installation operations.
Must be in the format projects/*/secrets/*/versions/*. The file itself must
be in a JSON format.
Corresponds to the JSON property npmrcEnvironmentVariablesSecretVersion
3380 3381 3382 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3380 def npmrc_environment_variables_secret_version @npmrc_environment_variables_secret_version end |
#service_account ⇒ String
Optional. The service account to run workflow invocations under.
Corresponds to the JSON property serviceAccount
3385 3386 3387 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3385 def service_account @service_account end |
#set_authenticated_user_admin ⇒ Boolean Also known as: set_authenticated_user_admin?
Optional. Input only. If set to true, the authenticated user will be granted
the roles/dataform.admin role on the created repository. To modify access to
the created repository later apply setIamPolicy from https://cloud.google.com/
dataform/reference/rest#rest-resource:-v1beta1.projects.locations.repositories
Corresponds to the JSON property setAuthenticatedUserAdmin
3393 3394 3395 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3393 def set_authenticated_user_admin @set_authenticated_user_admin end |
#team_folder_name ⇒ String
Output only. The resource name of the TeamFolder that this Repository is
associated with. This should take the format: projects/project/locations/
location/teamFolders/teamFolder. If this is not set, the Repository is not
associated with a TeamFolder.
Corresponds to the JSON property teamFolderName
3402 3403 3404 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3402 def team_folder_name @team_folder_name end |
#workspace_compilation_overrides ⇒ Google::Apis::DataformV1beta1::WorkspaceCompilationOverrides
Configures workspace compilation overrides for a repository. Primarily used by
the UI (console.cloud.google.com). schema_suffix and table_prefix can
have a special expression - $workspaceName`, which refers to the workspace
name from which the compilation results will be created. API callers are
expected to resolve the expression in these overrides and provide them
explicitly incode_compilation_config(https://cloud.google.com/dataform/
reference/rest/v1beta1/projects.locations.repositories.compilationResults#
codecompilationconfig) when creating workspace-scoped compilation results.
Corresponds to the JSON propertyworkspaceCompilationOverrides`
3414 3415 3416 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3414 def workspace_compilation_overrides @workspace_compilation_overrides end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3421 3422 3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 3433 3434 3435 3436 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3421 def update!(**args) @containing_folder = args[:containing_folder] if args.key?(:containing_folder) @create_time = args[:create_time] if args.key?(:create_time) @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state) @display_name = args[:display_name] if args.key?(:display_name) @git_remote_settings = args[:git_remote_settings] if args.key?(:git_remote_settings) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @npmrc_environment_variables_secret_version = args[:npmrc_environment_variables_secret_version] if args.key?(:npmrc_environment_variables_secret_version) @service_account = args[:service_account] if args.key?(:service_account) @set_authenticated_user_admin = args[:set_authenticated_user_admin] if args.key?(:set_authenticated_user_admin) @team_folder_name = args[:team_folder_name] if args.key?(:team_folder_name) @workspace_compilation_overrides = args[:workspace_compilation_overrides] if args.key?(:workspace_compilation_overrides) end |