Class: Google::Apis::DataformV1beta1::ResetWorkspaceChangesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::ResetWorkspaceChangesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
ResetWorkspaceChanges request message.
Instance Attribute Summary collapse
-
#clean ⇒ Boolean
(also: #clean?)
Optional.
-
#paths ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResetWorkspaceChangesRequest
constructor
A new instance of ResetWorkspaceChangesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResetWorkspaceChangesRequest
Returns a new instance of ResetWorkspaceChangesRequest.
3608 3609 3610 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clean ⇒ Boolean Also known as: clean?
Optional. If set to true, untracked files will be deleted.
Corresponds to the JSON property clean
3599 3600 3601 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3599 def clean @clean end |
#paths ⇒ Array<String>
Optional. Full file paths to reset back to their committed state including
filename, rooted at workspace root. If left empty, all files will be reset.
Corresponds to the JSON property paths
3606 3607 3608 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3606 def paths @paths end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3613 3614 3615 3616 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3613 def update!(**args) @clean = args[:clean] if args.key?(:clean) @paths = args[:paths] if args.key?(:paths) end |