Class: Google::Apis::DataformV1beta1::ResetWorkspaceChangesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::ResetWorkspaceChangesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
ResetWorkspaceChanges request message.
Instance Attribute Summary collapse
-
#clean ⇒ Boolean
(also: #clean?)
Optional.
-
#paths ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResetWorkspaceChangesRequest
constructor
A new instance of ResetWorkspaceChangesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResetWorkspaceChangesRequest
Returns a new instance of ResetWorkspaceChangesRequest.
3497 3498 3499 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clean ⇒ Boolean Also known as: clean?
Optional. If set to true, untracked files will be deleted.
Corresponds to the JSON property clean
3488 3489 3490 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3488 def clean @clean end |
#paths ⇒ Array<String>
Optional. Full file paths to reset back to their committed state including
filename, rooted at workspace root. If left empty, all files will be reset.
Corresponds to the JSON property paths
3495 3496 3497 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3495 def paths @paths end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3502 3503 3504 3505 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3502 def update!(**args) @clean = args[:clean] if args.key?(:clean) @paths = args[:paths] if args.key?(:paths) end |