Class: Google::Apis::DataformV1beta1::ResetWorkspaceChangesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::ResetWorkspaceChangesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
ResetWorkspaceChanges request message.
Instance Attribute Summary collapse
-
#clean ⇒ Boolean
(also: #clean?)
Optional.
-
#paths ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResetWorkspaceChangesRequest
constructor
A new instance of ResetWorkspaceChangesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResetWorkspaceChangesRequest
Returns a new instance of ResetWorkspaceChangesRequest.
3455 3456 3457 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clean ⇒ Boolean Also known as: clean?
Optional. If set to true, untracked files will be deleted.
Corresponds to the JSON property clean
3446 3447 3448 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3446 def clean @clean end |
#paths ⇒ Array<String>
Optional. Full file paths to reset back to their committed state including
filename, rooted at workspace root. If left empty, all files will be reset.
Corresponds to the JSON property paths
3453 3454 3455 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3453 def paths @paths end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3460 3461 3462 3463 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3460 def update!(**args) @clean = args[:clean] if args.key?(:clean) @paths = args[:paths] if args.key?(:paths) end |