Class: Google::Apis::DataformV1beta1::RootContentsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a single content entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RootContentsEntry

Returns a new instance of RootContentsEntry.



3494
3495
3496
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folderGoogle::Apis::DataformV1beta1::Folder

Represents a Dataform Folder. This is a resource that is used to organize Files and other Folders and provide hierarchical access controls. Corresponds to the JSON property folder



3487
3488
3489
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3487

def folder
  @folder
end

#repositoryGoogle::Apis::DataformV1beta1::Repository

Represents a Dataform Git repository. Corresponds to the JSON property repository



3492
3493
3494
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3492

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3499
3500
3501
3502
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3499

def update!(**args)
  @folder = args[:folder] if args.key?(:folder)
  @repository = args[:repository] if args.key?(:repository)
end