Class: Google::Apis::DataformV1beta1::ScheduledExecutionRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

A record of an attempt to create a workflow invocation for this workflow config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScheduledExecutionRecord

Returns a new instance of ScheduledExecutionRecord.



3532
3533
3534
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_statusGoogle::Apis::DataformV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property errorStatus



3518
3519
3520
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3518

def error_status
  @error_status
end

#execution_timeString

Output only. The timestamp of this execution attempt. Corresponds to the JSON property executionTime

Returns:

  • (String)


3523
3524
3525
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3523

def execution_time
  @execution_time
end

#workflow_invocationString

The name of the created workflow invocation, if one was successfully created. Must be in the format projects/*/locations/*/repositories/*/ workflowInvocations/*. Corresponds to the JSON property workflowInvocation

Returns:

  • (String)


3530
3531
3532
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3530

def workflow_invocation
  @workflow_invocation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3537
3538
3539
3540
3541
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3537

def update!(**args)
  @error_status = args[:error_status] if args.key?(:error_status)
  @execution_time = args[:execution_time] if args.key?(:execution_time)
  @workflow_invocation = args[:workflow_invocation] if args.key?(:workflow_invocation)
end