Class: Google::Apis::DataformV1beta1::SqlDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Definition of a SQL Data Preparation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlDefinition

Returns a new instance of SqlDefinition.



3773
3774
3775
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_tableGoogle::Apis::DataformV1beta1::ErrorTable

Error table information, used to write error data into a BigQuery table. Corresponds to the JSON property errorTable



3760
3761
3762
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3760

def error_table
  @error_table
end

#loadGoogle::Apis::DataformV1beta1::LoadConfig

Simplified load configuration for actions Corresponds to the JSON property load



3765
3766
3767
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3765

def load
  @load
end

#queryString

The SQL query representing the data preparation steps. Formatted as a Pipe SQL query statement. Corresponds to the JSON property query

Returns:

  • (String)


3771
3772
3773
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3771

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3778
3779
3780
3781
3782
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3778

def update!(**args)
  @error_table = args[:error_table] if args.key?(:error_table)
  @load = args[:load] if args.key?(:load)
  @query = args[:query] if args.key?(:query)
end