Class: Google::Apis::DataformV1beta1::TableUpdateTrigger

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a table update trigger configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableUpdateTrigger

Returns a new instance of TableUpdateTrigger.



3875
3876
3877
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3875

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tableGoogle::Apis::DataformV1beta1::Target

Represents an action identifier. If the action writes output, the output will be written to the referenced database object. Corresponds to the JSON property table



3866
3867
3868
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3866

def table
  @table
end

#trigger_update_timeString

Output only. The modification time of this table that resulted in an invocation of the workflow. This would be updated by the triggering service after a successful workflow invocation. Corresponds to the JSON property triggerUpdateTime

Returns:

  • (String)


3873
3874
3875
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3873

def trigger_update_time
  @trigger_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3880
3881
3882
3883
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3880

def update!(**args)
  @table = args[:table] if args.key?(:table)
  @trigger_update_time = args[:trigger_update_time] if args.key?(:trigger_update_time)
end