Class: Google::Apis::DataformV1beta1::TeamFolderContentsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a single content entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TeamFolderContentsEntry

Returns a new instance of TeamFolderContentsEntry.



3952
3953
3954
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3952

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folderGoogle::Apis::DataformV1beta1::Folder

Represents a Dataform Folder. This is a resource that is used to organize Files and other Folders and provide hierarchical access controls. Corresponds to the JSON property folder



3945
3946
3947
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3945

def folder
  @folder
end

#repositoryGoogle::Apis::DataformV1beta1::Repository

Represents a Dataform Git repository. Corresponds to the JSON property repository



3950
3951
3952
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3950

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3957
3958
3959
3960
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3957

def update!(**args)
  @folder = args[:folder] if args.key?(:folder)
  @repository = args[:repository] if args.key?(:repository)
end