Class: Google::Apis::DataformV1beta1::TriggerEvaluationRecord
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::TriggerEvaluationRecord
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
A record of an attempt to evaluate trigger conditions.
Instance Attribute Summary collapse
-
#evaluation_time ⇒ String
Output only.
-
#status ⇒ Google::Apis::DataformV1beta1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TriggerEvaluationRecord
constructor
A new instance of TriggerEvaluationRecord.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TriggerEvaluationRecord
Returns a new instance of TriggerEvaluationRecord.
4377 4378 4379 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evaluation_time ⇒ String
Output only. The timestamp of this trigger evaluation attempt.
Corresponds to the JSON property evaluationTime
4365 4366 4367 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4365 def evaluation_time @evaluation_time end |
#status ⇒ Google::Apis::DataformV1beta1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
4375 4376 4377 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4375 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4382 4383 4384 4385 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4382 def update!(**args) @evaluation_time = args[:evaluation_time] if args.key?(:evaluation_time) @status = args[:status] if args.key?(:status) end |