Class: Google::Apis::DataformV1beta1::TriggerEvaluationRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

A record of an attempt to evaluate trigger conditions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TriggerEvaluationRecord

Returns a new instance of TriggerEvaluationRecord.



4188
4189
4190
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#evaluation_timeString

Output only. The timestamp of this trigger evaluation attempt. Corresponds to the JSON property evaluationTime

Returns:

  • (String)


4176
4177
4178
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4176

def evaluation_time
  @evaluation_time
end

#statusGoogle::Apis::DataformV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



4186
4187
4188
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4186

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4193
4194
4195
4196
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4193

def update!(**args)
  @evaluation_time = args[:evaluation_time] if args.key?(:evaluation_time)
  @status = args[:status] if args.key?(:status)
end