Class: Google::Apis::DataformV1beta1::UncommittedFileChange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents the Git state of a file with uncommitted changes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UncommittedFileChange

Returns a new instance of UncommittedFileChange.



4002
4003
4004
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pathString

The file's full path including filename, relative to the workspace root. Corresponds to the JSON property path

Returns:

  • (String)


3995
3996
3997
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 3995

def path
  @path
end

#stateString

Output only. Indicates the status of the file. Corresponds to the JSON property state

Returns:

  • (String)


4000
4001
4002
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4000

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4007
4008
4009
4010
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4007

def update!(**args)
  @path = args[:path] if args.key?(:path)
  @state = args[:state] if args.key?(:state)
end