Class: Google::Apis::DataformV1beta1::WorkflowConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a Dataform workflow configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkflowConfig

Returns a new instance of WorkflowConfig.



4295
4296
4297
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp of when the WorkflowConfig was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4231
4232
4233
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4231

def create_time
  @create_time
end

#cron_scheduleString

Optional. Optional schedule (in cron format) for automatic execution of this workflow config. Corresponds to the JSON property cronSchedule

Returns:

  • (String)


4237
4238
4239
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4237

def cron_schedule
  @cron_schedule
end

#disabledBoolean Also known as: disabled?

Optional. Disables automatic creation of workflow invocations. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


4242
4243
4244
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4242

def disabled
  @disabled
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


4250
4251
4252
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4250

def 
  @internal_metadata
end

#invocation_configGoogle::Apis::DataformV1beta1::InvocationConfig

Includes various configuration options for a workflow invocation. If both included_targets and included_tags are unset, all actions will be included. Corresponds to the JSON property invocationConfig



4256
4257
4258
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4256

def invocation_config
  @invocation_config
end

#nameString

Identifier. The workflow config's name. Corresponds to the JSON property name

Returns:

  • (String)


4261
4262
4263
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4261

def name
  @name
end

#recent_scheduled_execution_recordsArray<Google::Apis::DataformV1beta1::ScheduledExecutionRecord>

Output only. Records of the 10 most recent scheduled execution attempts, ordered in descending order of execution_time. Updated whenever automatic creation of a workflow invocation is triggered by cron_schedule. Corresponds to the JSON property recentScheduledExecutionRecords



4268
4269
4270
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4268

def recent_scheduled_execution_records
  @recent_scheduled_execution_records
end

#release_configString

Required. The name of the release config whose release_compilation_result should be executed. Must be in the format projects/*/locations/*/repositories/ */releaseConfigs/*. Corresponds to the JSON property releaseConfig

Returns:

  • (String)


4275
4276
4277
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4275

def release_config
  @release_config
end

#time_zoneString

Optional. Specifies the time zone to be used when interpreting cron_schedule. Must be a time zone name from the time zone database. If left unspecified, the default is UTC. Corresponds to the JSON property timeZone

Returns:

  • (String)


4283
4284
4285
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4283

def time_zone
  @time_zone
end

#update_timeString

Output only. The timestamp of when the WorkflowConfig was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4288
4289
4290
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4288

def update_time
  @update_time
end

#workflow_trigger_configGoogle::Apis::DataformV1beta1::WorkflowTriggerConfig

Represents a trigger configuration for a workflow. Corresponds to the JSON property workflowTriggerConfig



4293
4294
4295
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4293

def workflow_trigger_config
  @workflow_trigger_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4300
4301
4302
4303
4304
4305
4306
4307
4308
4309
4310
4311
4312
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4300

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @cron_schedule = args[:cron_schedule] if args.key?(:cron_schedule)
  @disabled = args[:disabled] if args.key?(:disabled)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @invocation_config = args[:invocation_config] if args.key?(:invocation_config)
  @name = args[:name] if args.key?(:name)
  @recent_scheduled_execution_records = args[:recent_scheduled_execution_records] if args.key?(:recent_scheduled_execution_records)
  @release_config = args[:release_config] if args.key?(:release_config)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @update_time = args[:update_time] if args.key?(:update_time)
  @workflow_trigger_config = args[:workflow_trigger_config] if args.key?(:workflow_trigger_config)
end