Class: Google::Apis::DataformV1beta1::WorkflowConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::WorkflowConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a Dataform workflow configuration.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#cron_schedule ⇒ String
Optional.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#internal_metadata ⇒ String
Output only.
-
#invocation_config ⇒ Google::Apis::DataformV1beta1::InvocationConfig
Includes various configuration options for a workflow invocation.
-
#name ⇒ String
Identifier.
-
#recent_scheduled_execution_records ⇒ Array<Google::Apis::DataformV1beta1::ScheduledExecutionRecord>
Output only.
-
#release_config ⇒ String
Required.
-
#time_zone ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkflowConfig
constructor
A new instance of WorkflowConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkflowConfig
Returns a new instance of WorkflowConfig.
4114 4115 4116 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4114 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp of when the WorkflowConfig was created.
Corresponds to the JSON property createTime
4056 4057 4058 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4056 def create_time @create_time end |
#cron_schedule ⇒ String
Optional. Optional schedule (in cron format) for automatic execution of this
workflow config.
Corresponds to the JSON property cronSchedule
4062 4063 4064 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4062 def cron_schedule @cron_schedule end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. Disables automatic creation of workflow invocations.
Corresponds to the JSON property disabled
4067 4068 4069 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4067 def disabled @disabled end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
4075 4076 4077 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4075 def @internal_metadata end |
#invocation_config ⇒ Google::Apis::DataformV1beta1::InvocationConfig
Includes various configuration options for a workflow invocation. If both
included_targets and included_tags are unset, all actions will be included.
Corresponds to the JSON property invocationConfig
4081 4082 4083 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4081 def invocation_config @invocation_config end |
#name ⇒ String
Identifier. The workflow config's name.
Corresponds to the JSON property name
4086 4087 4088 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4086 def name @name end |
#recent_scheduled_execution_records ⇒ Array<Google::Apis::DataformV1beta1::ScheduledExecutionRecord>
Output only. Records of the 10 most recent scheduled execution attempts,
ordered in descending order of execution_time. Updated whenever automatic
creation of a workflow invocation is triggered by cron_schedule.
Corresponds to the JSON property recentScheduledExecutionRecords
4093 4094 4095 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4093 def recent_scheduled_execution_records @recent_scheduled_execution_records end |
#release_config ⇒ String
Required. The name of the release config whose release_compilation_result
should be executed. Must be in the format projects/*/locations/*/repositories/
*/releaseConfigs/*.
Corresponds to the JSON property releaseConfig
4100 4101 4102 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4100 def release_config @release_config end |
#time_zone ⇒ String
Optional. Specifies the time zone to be used when interpreting cron_schedule.
Must be a time zone name from the time zone database (https://en.wikipedia.org/
wiki/List_of_tz_database_time_zones). If left unspecified, the default is UTC.
Corresponds to the JSON property timeZone
4107 4108 4109 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4107 def time_zone @time_zone end |
#update_time ⇒ String
Output only. The timestamp of when the WorkflowConfig was last updated.
Corresponds to the JSON property updateTime
4112 4113 4114 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4112 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4119 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @cron_schedule = args[:cron_schedule] if args.key?(:cron_schedule) @disabled = args[:disabled] if args.key?(:disabled) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @invocation_config = args[:invocation_config] if args.key?(:invocation_config) @name = args[:name] if args.key?(:name) @recent_scheduled_execution_records = args[:recent_scheduled_execution_records] if args.key?(:recent_scheduled_execution_records) @release_config = args[:release_config] if args.key?(:release_config) @time_zone = args[:time_zone] if args.key?(:time_zone) @update_time = args[:update_time] if args.key?(:update_time) end |