Class: Google::Apis::DataformV1beta1::WorkflowInvocation
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::WorkflowInvocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a single invocation of a compilation result.
Instance Attribute Summary collapse
-
#compilation_result ⇒ String
Immutable.
-
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
-
#internal_metadata ⇒ String
Output only.
-
#invocation_config ⇒ Google::Apis::DataformV1beta1::InvocationConfig
Includes various configuration options for a workflow invocation.
-
#invocation_timing ⇒ Google::Apis::DataformV1beta1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#name ⇒ String
Output only.
-
#pipeline_config ⇒ Google::Apis::DataformV1beta1::PipelineConfig
Defines the pipeline type and path within the Git repository.
-
#private_resource_metadata ⇒ Google::Apis::DataformV1beta1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
-
#resolved_compilation_result ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#workflow_config ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkflowInvocation
constructor
A new instance of WorkflowInvocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkflowInvocation
Returns a new instance of WorkflowInvocation.
4573 4574 4575 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4573 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compilation_result ⇒ String
Immutable. The name of the compilation result to use for this invocation. Must
be in the format projects/*/locations/*/repositories/*/compilationResults/*.
Corresponds to the JSON property compilationResult
4512 4513 4514 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4512 def compilation_result @compilation_result end |
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
Corresponds to the JSON property dataEncryptionState
4517 4518 4519 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4517 def data_encryption_state @data_encryption_state end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
4524 4525 4526 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4524 def @internal_metadata end |
#invocation_config ⇒ Google::Apis::DataformV1beta1::InvocationConfig
Includes various configuration options for a workflow invocation. If both
included_targets and included_tags are unset, all actions will be included.
Corresponds to the JSON property invocationConfig
4530 4531 4532 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4530 def invocation_config @invocation_config end |
#invocation_timing ⇒ Google::Apis::DataformV1beta1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property invocationTiming
4538 4539 4540 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4538 def invocation_timing @invocation_timing end |
#name ⇒ String
Output only. The workflow invocation's name.
Corresponds to the JSON property name
4543 4544 4545 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4543 def name @name end |
#pipeline_config ⇒ Google::Apis::DataformV1beta1::PipelineConfig
Defines the pipeline type and path within the Git repository.
Corresponds to the JSON property pipelineConfig
4548 4549 4550 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4548 def pipeline_config @pipeline_config end |
#private_resource_metadata ⇒ Google::Apis::DataformV1beta1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
Corresponds to the JSON property privateResourceMetadata
4553 4554 4555 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4553 def @private_resource_metadata end |
#resolved_compilation_result ⇒ String
Output only. The resolved compilation result that was used to create this
invocation. Will be in the format projects/*/locations/*/repositories/*/
compilationResults/*.
Corresponds to the JSON property resolvedCompilationResult
4560 4561 4562 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4560 def resolved_compilation_result @resolved_compilation_result end |
#state ⇒ String
Output only. This workflow invocation's current state.
Corresponds to the JSON property state
4565 4566 4567 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4565 def state @state end |
#workflow_config ⇒ String
Immutable. The name of the workflow config to invoke. Must be in the format
projects/*/locations/*/repositories/*/workflowConfigs/*.
Corresponds to the JSON property workflowConfig
4571 4572 4573 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4571 def workflow_config @workflow_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 4589 4590 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4578 def update!(**args) @compilation_result = args[:compilation_result] if args.key?(:compilation_result) @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @invocation_config = args[:invocation_config] if args.key?(:invocation_config) @invocation_timing = args[:invocation_timing] if args.key?(:invocation_timing) @name = args[:name] if args.key?(:name) @pipeline_config = args[:pipeline_config] if args.key?(:pipeline_config) @private_resource_metadata = args[:private_resource_metadata] if args.key?(:private_resource_metadata) @resolved_compilation_result = args[:resolved_compilation_result] if args.key?(:resolved_compilation_result) @state = args[:state] if args.key?(:state) @workflow_config = args[:workflow_config] if args.key?(:workflow_config) end |