Class: Google::Apis::DataformV1beta1::WorkflowInvocation
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::WorkflowInvocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a single invocation of a compilation result.
Instance Attribute Summary collapse
-
#compilation_result ⇒ String
Immutable.
-
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
-
#internal_metadata ⇒ String
Output only.
-
#invocation_config ⇒ Google::Apis::DataformV1beta1::InvocationConfig
Includes various configuration options for a workflow invocation.
-
#invocation_timing ⇒ Google::Apis::DataformV1beta1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#name ⇒ String
Output only.
-
#private_resource_metadata ⇒ Google::Apis::DataformV1beta1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
-
#resolved_compilation_result ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#workflow_config ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkflowInvocation
constructor
A new instance of WorkflowInvocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkflowInvocation
Returns a new instance of WorkflowInvocation.
4267 4268 4269 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compilation_result ⇒ String
Immutable. The name of the compilation result to use for this invocation. Must
be in the format projects/*/locations/*/repositories/*/compilationResults/*.
Corresponds to the JSON property compilationResult
4211 4212 4213 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4211 def compilation_result @compilation_result end |
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
Corresponds to the JSON property dataEncryptionState
4216 4217 4218 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4216 def data_encryption_state @data_encryption_state end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
4223 4224 4225 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4223 def @internal_metadata end |
#invocation_config ⇒ Google::Apis::DataformV1beta1::InvocationConfig
Includes various configuration options for a workflow invocation. If both
included_targets and included_tags are unset, all actions will be included.
Corresponds to the JSON property invocationConfig
4229 4230 4231 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4229 def invocation_config @invocation_config end |
#invocation_timing ⇒ Google::Apis::DataformV1beta1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property invocationTiming
4237 4238 4239 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4237 def invocation_timing @invocation_timing end |
#name ⇒ String
Output only. The workflow invocation's name.
Corresponds to the JSON property name
4242 4243 4244 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4242 def name @name end |
#private_resource_metadata ⇒ Google::Apis::DataformV1beta1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
Corresponds to the JSON property privateResourceMetadata
4247 4248 4249 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4247 def @private_resource_metadata end |
#resolved_compilation_result ⇒ String
Output only. The resolved compilation result that was used to create this
invocation. Will be in the format projects/*/locations/*/repositories/*/
compilationResults/*.
Corresponds to the JSON property resolvedCompilationResult
4254 4255 4256 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4254 def resolved_compilation_result @resolved_compilation_result end |
#state ⇒ String
Output only. This workflow invocation's current state.
Corresponds to the JSON property state
4259 4260 4261 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4259 def state @state end |
#workflow_config ⇒ String
Immutable. The name of the workflow config to invoke. Must be in the format
projects/*/locations/*/repositories/*/workflowConfigs/*.
Corresponds to the JSON property workflowConfig
4265 4266 4267 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4265 def workflow_config @workflow_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4272 def update!(**args) @compilation_result = args[:compilation_result] if args.key?(:compilation_result) @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @invocation_config = args[:invocation_config] if args.key?(:invocation_config) @invocation_timing = args[:invocation_timing] if args.key?(:invocation_timing) @name = args[:name] if args.key?(:name) @private_resource_metadata = args[:private_resource_metadata] if args.key?(:private_resource_metadata) @resolved_compilation_result = args[:resolved_compilation_result] if args.key?(:resolved_compilation_result) @state = args[:state] if args.key?(:state) @workflow_config = args[:workflow_config] if args.key?(:workflow_config) end |