Class: Google::Apis::DataformV1beta1::WorkflowInvocationAction
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::WorkflowInvocationAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a single action in a workflow invocation.
Instance Attribute Summary collapse
-
#bigquery_action ⇒ Google::Apis::DataformV1beta1::BigQueryAction
Represents a workflow action that will run against BigQuery.
-
#canonical_target ⇒ Google::Apis::DataformV1beta1::Target
Represents an action identifier.
-
#data_preparation_action ⇒ Google::Apis::DataformV1beta1::DataPreparationAction
Represents a workflow action that will run a Data Preparation.
-
#failure_reason ⇒ String
Output only.
-
#internal_metadata ⇒ String
Output only.
-
#invocation_timing ⇒ Google::Apis::DataformV1beta1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#notebook_action ⇒ Google::Apis::DataformV1beta1::NotebookAction
Represents a workflow action that will run against a Notebook runtime.
-
#state ⇒ String
Output only.
-
#target ⇒ Google::Apis::DataformV1beta1::Target
Represents an action identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkflowInvocationAction
constructor
A new instance of WorkflowInvocationAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkflowInvocationAction
Returns a new instance of WorkflowInvocationAction.
4272 4273 4274 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_action ⇒ Google::Apis::DataformV1beta1::BigQueryAction
Represents a workflow action that will run against BigQuery.
Corresponds to the JSON property bigqueryAction
4223 4224 4225 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4223 def bigquery_action @bigquery_action end |
#canonical_target ⇒ Google::Apis::DataformV1beta1::Target
Represents an action identifier. If the action writes output, the output will
be written to the referenced database object.
Corresponds to the JSON property canonicalTarget
4229 4230 4231 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4229 def canonical_target @canonical_target end |
#data_preparation_action ⇒ Google::Apis::DataformV1beta1::DataPreparationAction
Represents a workflow action that will run a Data Preparation.
Corresponds to the JSON property dataPreparationAction
4234 4235 4236 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4234 def data_preparation_action @data_preparation_action end |
#failure_reason ⇒ String
Output only. If and only if action's state is FAILED a failure reason is set.
Corresponds to the JSON property failureReason
4239 4240 4241 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4239 def failure_reason @failure_reason end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
4246 4247 4248 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4246 def @internal_metadata end |
#invocation_timing ⇒ Google::Apis::DataformV1beta1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property invocationTiming
4254 4255 4256 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4254 def invocation_timing @invocation_timing end |
#notebook_action ⇒ Google::Apis::DataformV1beta1::NotebookAction
Represents a workflow action that will run against a Notebook runtime.
Corresponds to the JSON property notebookAction
4259 4260 4261 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4259 def notebook_action @notebook_action end |
#state ⇒ String
Output only. This action's current state.
Corresponds to the JSON property state
4264 4265 4266 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4264 def state @state end |
#target ⇒ Google::Apis::DataformV1beta1::Target
Represents an action identifier. If the action writes output, the output will
be written to the referenced database object.
Corresponds to the JSON property target
4270 4271 4272 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4270 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4277 def update!(**args) @bigquery_action = args[:bigquery_action] if args.key?(:bigquery_action) @canonical_target = args[:canonical_target] if args.key?(:canonical_target) @data_preparation_action = args[:data_preparation_action] if args.key?(:data_preparation_action) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @invocation_timing = args[:invocation_timing] if args.key?(:invocation_timing) @notebook_action = args[:notebook_action] if args.key?(:notebook_action) @state = args[:state] if args.key?(:state) @target = args[:target] if args.key?(:target) end |