Class: Google::Apis::DataformV1beta1::WorkflowInvocationAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a single action in a workflow invocation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkflowInvocationAction

Returns a new instance of WorkflowInvocationAction.



4236
4237
4238
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_actionGoogle::Apis::DataformV1beta1::BigQueryAction

Represents a workflow action that will run against BigQuery. Corresponds to the JSON property bigqueryAction



4187
4188
4189
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4187

def bigquery_action
  @bigquery_action
end

#canonical_targetGoogle::Apis::DataformV1beta1::Target

Represents an action identifier. If the action writes output, the output will be written to the referenced database object. Corresponds to the JSON property canonicalTarget



4193
4194
4195
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4193

def canonical_target
  @canonical_target
end

#data_preparation_actionGoogle::Apis::DataformV1beta1::DataPreparationAction

Represents a workflow action that will run a Data Preparation. Corresponds to the JSON property dataPreparationAction



4198
4199
4200
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4198

def data_preparation_action
  @data_preparation_action
end

#failure_reasonString

Output only. If and only if action's state is FAILED a failure reason is set. Corresponds to the JSON property failureReason

Returns:

  • (String)


4203
4204
4205
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4203

def failure_reason
  @failure_reason
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


4210
4211
4212
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4210

def 
  @internal_metadata
end

#invocation_timingGoogle::Apis::DataformV1beta1::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property invocationTiming



4218
4219
4220
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4218

def invocation_timing
  @invocation_timing
end

#notebook_actionGoogle::Apis::DataformV1beta1::NotebookAction

Represents a workflow action that will run against a Notebook runtime. Corresponds to the JSON property notebookAction



4223
4224
4225
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4223

def notebook_action
  @notebook_action
end

#stateString

Output only. This action's current state. Corresponds to the JSON property state

Returns:

  • (String)


4228
4229
4230
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4228

def state
  @state
end

#targetGoogle::Apis::DataformV1beta1::Target

Represents an action identifier. If the action writes output, the output will be written to the referenced database object. Corresponds to the JSON property target



4234
4235
4236
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4234

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4241

def update!(**args)
  @bigquery_action = args[:bigquery_action] if args.key?(:bigquery_action)
  @canonical_target = args[:canonical_target] if args.key?(:canonical_target)
  @data_preparation_action = args[:data_preparation_action] if args.key?(:data_preparation_action)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @invocation_timing = args[:invocation_timing] if args.key?(:invocation_timing)
  @notebook_action = args[:notebook_action] if args.key?(:notebook_action)
  @state = args[:state] if args.key?(:state)
  @target = args[:target] if args.key?(:target)
end