Class: Google::Apis::DataformV1beta1::WorkflowTriggerConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::WorkflowTriggerConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a trigger configuration for a workflow.
Instance Attribute Summary collapse
-
#condition ⇒ String
Optional.
-
#last_successful_evaluation_time ⇒ String
Output only.
-
#max_wait_duration ⇒ String
Optional.
-
#min_execution_duration ⇒ String
Optional.
-
#recent_trigger_evaluation_records ⇒ Array<Google::Apis::DataformV1beta1::TriggerEvaluationRecord>
Output only.
-
#workflow_triggers ⇒ Array<Google::Apis::DataformV1beta1::WorkflowTrigger>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkflowTriggerConfig
constructor
A new instance of WorkflowTriggerConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkflowTriggerConfig
Returns a new instance of WorkflowTriggerConfig.
4419 4420 4421 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ String
Optional. The condition to use when triggering the workflow.
Corresponds to the JSON property condition
4386 4387 4388 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4386 def condition @condition end |
#last_successful_evaluation_time ⇒ String
Output only. The timestamp of the last successful trigger evaluation.
Corresponds to the JSON property lastSuccessfulEvaluationTime
4391 4392 4393 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4391 def last_successful_evaluation_time @last_successful_evaluation_time end |
#max_wait_duration ⇒ String
Optional. The effective maximum wait time duration for the trigger condition
to be met. If not specified, the workflow won't be triggered until conditions
are met.
Corresponds to the JSON property maxWaitDuration
4398 4399 4400 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4398 def max_wait_duration @max_wait_duration end |
#min_execution_duration ⇒ String
Optional. Minimum duration between two consecutive executions. If not
specified, the workflow will be executed every time trigger conditions are met
and no ongoing workflow execution.
Corresponds to the JSON property minExecutionDuration
4405 4406 4407 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4405 def min_execution_duration @min_execution_duration end |
#recent_trigger_evaluation_records ⇒ Array<Google::Apis::DataformV1beta1::TriggerEvaluationRecord>
Output only. Records of the 10 most recent trigger evaluations, ordered in
descending order of evaluation_time. Updated whenever the service evaluates
the trigger conditions (via polling or upon receiving a push event).
Corresponds to the JSON property recentTriggerEvaluationRecords
4412 4413 4414 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4412 def recent_trigger_evaluation_records @recent_trigger_evaluation_records end |
#workflow_triggers ⇒ Array<Google::Apis::DataformV1beta1::WorkflowTrigger>
Required. The trigger definitions to invoke a workflow.
Corresponds to the JSON property workflowTriggers
4417 4418 4419 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4417 def workflow_triggers @workflow_triggers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4424 4425 4426 4427 4428 4429 4430 4431 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4424 def update!(**args) @condition = args[:condition] if args.key?(:condition) @last_successful_evaluation_time = args[:last_successful_evaluation_time] if args.key?(:last_successful_evaluation_time) @max_wait_duration = args[:max_wait_duration] if args.key?(:max_wait_duration) @min_execution_duration = args[:min_execution_duration] if args.key?(:min_execution_duration) @recent_trigger_evaluation_records = args[:recent_trigger_evaluation_records] if args.key?(:recent_trigger_evaluation_records) @workflow_triggers = args[:workflow_triggers] if args.key?(:workflow_triggers) end |