Class: Google::Apis::DataformV1beta1::Workspace
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1beta1::Workspace
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb
Overview
Represents a Dataform Git workspace.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
-
#depth ⇒ Fixnum
Optional.
-
#disable_moves ⇒ Boolean
(also: #disable_moves?)
Optional.
-
#enable_branch_management ⇒ Boolean
(also: #enable_branch_management?)
Immutable.
-
#internal_metadata ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#original_branch ⇒ String
Optional.
-
#private_resource_metadata ⇒ Google::Apis::DataformV1beta1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
-
#shallow ⇒ Boolean
(also: #shallow?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Workspace
constructor
A new instance of Workspace.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Workspace
Returns a new instance of Workspace.
4810 4811 4812 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp of when the workspace was created.
Corresponds to the JSON property createTime
4748 4749 4750 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4748 def create_time @create_time end |
#data_encryption_state ⇒ Google::Apis::DataformV1beta1::DataEncryptionState
Describes encryption state of a resource.
Corresponds to the JSON property dataEncryptionState
4753 4754 4755 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4753 def data_encryption_state @data_encryption_state end |
#depth ⇒ Fixnum
Optional. Input only. Immutable. The maximum depth of the Git repository to
checkout for this workspace. If defined and greater than 0, the Git repository
will be created as a shallow clone with the given depth, otherwise a full
clone will be performed. This field is available only for GitHub, Gitlab and
1p repositories with enabled branch management.
Corresponds to the JSON property depth
4762 4763 4764 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4762 def depth @depth end |
#disable_moves ⇒ Boolean Also known as: disable_moves?
Optional. If set to true, workspaces will not be moved if its linked
Repository is moved. Instead, it will be deleted.
Corresponds to the JSON property disableMoves
4768 4769 4770 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4768 def disable_moves @disable_moves end |
#enable_branch_management ⇒ Boolean Also known as: enable_branch_management?
Immutable. Controls the enablement of branch checkout for the workspace. When
set to True, the workspace will be allowed to checkout branches.
Corresponds to the JSON property enableBranchManagement
4775 4776 4777 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4775 def enable_branch_management @enable_branch_management end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
4783 4784 4785 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4783 def @internal_metadata end |
#name ⇒ String
Identifier. The workspace's name.
Corresponds to the JSON property name
4788 4789 4790 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4788 def name @name end |
#original_branch ⇒ String
Optional. Input only. Immutable. The name of the default upstream branch for
all pull/push operations in the remote repository for this workspace. If empty,
the HEAD branch from repository will be used.
Corresponds to the JSON property originalBranch
4795 4796 4797 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4795 def original_branch @original_branch end |
#private_resource_metadata ⇒ Google::Apis::DataformV1beta1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
Corresponds to the JSON property privateResourceMetadata
4800 4801 4802 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4800 def @private_resource_metadata end |
#shallow ⇒ Boolean Also known as: shallow?
Output only. If set to true, the workspace was created as a shallow clone.
Will be set to true if the depth field is set to a value greater than 0,
otherwise it will be set to false.
Corresponds to the JSON property shallow
4807 4808 4809 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4807 def shallow @shallow end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4815 4816 4817 4818 4819 4820 4821 4822 4823 4824 4825 4826 |
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4815 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state) @depth = args[:depth] if args.key?(:depth) @disable_moves = args[:disable_moves] if args.key?(:disable_moves) @enable_branch_management = args[:enable_branch_management] if args.key?(:enable_branch_management) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @name = args[:name] if args.key?(:name) @original_branch = args[:original_branch] if args.key?(:original_branch) @private_resource_metadata = args[:private_resource_metadata] if args.key?(:private_resource_metadata) @shallow = args[:shallow] if args.key?(:shallow) end |