Class: Google::Apis::DataformV1beta1::Workspace

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1beta1/classes.rb,
lib/google/apis/dataform_v1beta1/representations.rb,
lib/google/apis/dataform_v1beta1/representations.rb

Overview

Represents a Dataform Git workspace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Workspace

Returns a new instance of Workspace.



4336
4337
4338
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp of when the workspace was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4305
4306
4307
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4305

def create_time
  @create_time
end

#data_encryption_stateGoogle::Apis::DataformV1beta1::DataEncryptionState

Describes encryption state of a resource. Corresponds to the JSON property dataEncryptionState



4310
4311
4312
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4310

def data_encryption_state
  @data_encryption_state
end

#disable_movesBoolean Also known as: disable_moves?

Optional. If set to true, workspaces will not be moved if its linked Repository is moved. Instead, it will be deleted. Corresponds to the JSON property disableMoves

Returns:

  • (Boolean)


4316
4317
4318
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4316

def disable_moves
  @disable_moves
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


4324
4325
4326
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4324

def 
  @internal_metadata
end

#nameString

Identifier. The workspace's name. Corresponds to the JSON property name

Returns:

  • (String)


4329
4330
4331
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4329

def name
  @name
end

#private_resource_metadataGoogle::Apis::DataformV1beta1::PrivateResourceMetadata

Metadata used to identify if a resource is user scoped. Corresponds to the JSON property privateResourceMetadata



4334
4335
4336
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4334

def 
  @private_resource_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4341
4342
4343
4344
4345
4346
4347
4348
# File 'lib/google/apis/dataform_v1beta1/classes.rb', line 4341

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state)
  @disable_moves = args[:disable_moves] if args.key?(:disable_moves)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @name = args[:name] if args.key?(:name)
  @private_resource_metadata = args[:private_resource_metadata] if args.key?(:private_resource_metadata)
end